@@ -349,7 +349,10 @@ public class AnnotationUtils {
      *
      * <p>This constructor is public to permit tools that require a JavaBean
      * instance to operate.</p>
+     * @deprecated TODO Make private in 4.0.
      */
+    @Deprecated
     public AnnotationUtils() {
+        // empty
     }
 }
