@@ -45,13 +45,11 @@ import org.apache.commons.lang3.function.FailableFunction;
 import org.apache.commons.lang3.function.FailablePredicate;
 
 /**
- * Provides utility functions, and classes for working with the {@code java.util.stream} package, or more generally,
- * with Java 8 lambdas. More specifically, it attempts to address the fact that lambdas are supposed not to throw
- * Exceptions, at least not checked Exceptions, AKA instances of {@link Exception}. This enforces the use of constructs
- * like:
+ * Provides utility functions, and classes for working with the {@link java.util.stream} package, or more generally, with Java 8 lambdas. More specifically, it
+ * attempts to address the fact that lambdas are supposed not to throw Exceptions, at least not checked Exceptions, AKA instances of {@link Exception}. This
+ * enforces the use of constructs like:
  *
- * <pre>
- * {@code
+ * <pre>{@code
  * Consumer<java.lang.reflect.Method> consumer = m -> {
  *     try {
  *         m.invoke(o, args);
@@ -60,20 +58,17 @@ import org.apache.commons.lang3.function.FailablePredicate;
  *     }
  * };
  * stream.forEach(consumer);
- * }
- * </pre>
+ * }</pre>
  * <p>
  * Using a {@link FailableStream}, this can be rewritten as follows:
  * </p>
  *
- * <pre>
- * {@code
- * Streams.failable(stream).forEach((m) -> m.invoke(o, args));
- * }
- * </pre>
- *
- * Obviously, the second version is much more concise and the spirit of Lambda expressions is met better than in the
- * first version.
+ * <pre>{@code
+ * Streams.failable(stream).forEach(m -> m.invoke(o, args));
+ * }</pre>
+ * <p>
+ * Obviously, the second version is much more concise and the spirit of Lambda expressions is met better than in the first version.
+ * </p>
  *
  * @see Stream
  * @see Failable
@@ -307,7 +302,6 @@ public class Streams {
          * Performs a mutable reduction operation on the elements of this FailableStream. A mutable reduction is one in which
          * the reduced value is a mutable result container, such as an {@link ArrayList}, and elements are incorporated by
          * updating the state of the result rather than by replacing the result. This produces a result equivalent to:
-         *
          * <pre>
          * {@code
          *     R result = supplier.get();
@@ -316,29 +310,25 @@ public class Streams {
          *     return result;
          * }
          * </pre>
-         *
          * <p>
          * Like {@link #reduce(Object, BinaryOperator)}, {@code collect} operations can be parallelized without requiring
          * additional synchronization.
          * </p>
-         *
          * <p>
          * This is a terminal operation.
          * </p>
-         *
+         * <p>
          * Note There are many existing classes in the JDK whose signatures are well-suited for use with method references as
          * arguments to {@code collect()}. For example, the following will accumulate strings into an {@link ArrayList}:
-         *
+         * </p>
          * <pre>
          * {@code
          *     List<String> asList = stringStream.collect(ArrayList::new, ArrayList::add, ArrayList::addAll);
          * }
          * </pre>
-         *
          * <p>
          * The following will take a stream of strings and concatenates them into a single string:
          * </p>
-         *
          * <pre>
          * {@code
          *     String concat = stringStream.collect(StringBuilder::new, StringBuilder::append, StringBuilder::append).toString();
@@ -362,7 +352,6 @@ public class Streams {
 
         /**
          * Returns a FailableStream consisting of the elements of this stream that match the given FailablePredicate.
-         *
          * <p>
          * This is an intermediate operation.
          * </p>
@@ -379,11 +368,9 @@ public class Streams {
 
         /**
          * Performs an action for each element of this stream.
-         *
          * <p>
          * This is a terminal operation.
          * </p>
-         *
          * <p>
          * The behavior of this operation is explicitly nondeterministic. For parallel stream pipelines, this operation does
          * <em>not</em> guarantee to respect the encounter order of the stream, as doing so would sacrifice the benefit of
@@ -579,6 +566,18 @@ public class Streams {
         return new FailableStream<>(stream);
     }
 
+    /**
+     * Shorthand for {@code Streams.failableStream(value == null ? Stream.empty() : Stream.of(value))}.
+     *
+     * @param <T> the type of stream elements.
+     * @param value the single element of the new stream, may be {@code null}.
+     * @return the new FailableStream on {@code value} or an empty stream.
+     * @since 3.15.0
+     */
+    public static <T> FailableStream<T> failableStream(final T value) {
+        return failableStream(streamOf(value));
+    }
+
     /**
      * Shorthand for {@code Streams.failableStream(Streams.of(arrayValues))}.
      *
@@ -628,6 +627,18 @@ public class Streams {
         return of(collection).filter(Objects::nonNull);
     }
 
+    /**
+     * Streams the non-null element.
+     *
+     * @param <E> the type of elements in the collection.
+     * @param array the element to stream or null.
+     * @return A non-null stream that filters out a null element.
+     * @since 3.15.0
+     */
+    public static <E> Stream<E> nonNull(final E array) {
+        return nonNull(streamOf(array));
+    }
+
     /**
      * Streams the non-null elements of an array.
      *
@@ -816,14 +827,28 @@ public class Streams {
         return failableStream(stream);
     }
 
+    private static <T> Stream<T> streamOf(final T value) {
+        return value == null ? Stream.empty() : Stream.of(value);
+    }
+
     /**
      * Returns a {@link Collector} that accumulates the input elements into a new array.
      *
-     * @param pElementType Type of an element in the array.
+     * @param elementType Type of an element in the array.
      * @param <T> the type of the input elements
      * @return a {@link Collector} which collects all the input elements into an array, in encounter order
      */
-    public static <T> Collector<T, ?, T[]> toArray(final Class<T> pElementType) {
-        return new ArrayCollector<>(pElementType);
+    public static <T> Collector<T, ?, T[]> toArray(final Class<T> elementType) {
+        return new ArrayCollector<>(elementType);
+    }
+
+    /**
+     * Constructs a new instance.
+     *
+     * @deprecated Will be private in 4.0.0.
+     */
+    @Deprecated
+    public Streams() {
+        // empty
     }
 }
