@@ -16,12 +16,6 @@
  */
 package org.apache.commons.lang3;
 
-import static java.lang.annotation.ElementType.FIELD;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
-import static org.apache.commons.lang3.AnnotationUtilsTest.Stooge.CURLY;
-import static org.apache.commons.lang3.AnnotationUtilsTest.Stooge.LARRY;
-import static org.apache.commons.lang3.AnnotationUtilsTest.Stooge.MOE;
-import static org.apache.commons.lang3.AnnotationUtilsTest.Stooge.SHEMP;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
@@ -45,7 +39,79 @@ import org.junit.jupiter.api.Test;
 
 /**
  */
-public class AnnotationUtilsTest {
+public class AnnotationUtilsTest extends AbstractLangTest {
+    @Retention(RetentionPolicy.RUNTIME)
+    public @interface NestAnnotation {
+        boolean booleanValue();
+        boolean[] booleanValues();
+        byte byteValue();
+        byte[] byteValues();
+        char charValue();
+        char[] charValues();
+        double doubleValue();
+        double[] doubleValues();
+        float floatValue();
+        float[] floatValues();
+        int intValue();
+        int[] intValues();
+        long longValue();
+        long[] longValues();
+        short shortValue();
+        short[] shortValues();
+        Stooge stooge();
+        Stooge[] stooges();
+        String string();
+        String[] strings();
+        Class<?> type();
+        Class<?>[] types();
+    }
+
+    public enum Stooge {
+        MOE, LARRY, CURLY, JOE, SHEMP
+    }
+
+    @Target(ElementType.FIELD)
+    @Retention(RetentionPolicy.RUNTIME)
+    public @interface TestAnnotation {
+        boolean booleanValue();
+        boolean[] booleanValues();
+        byte byteValue();
+        byte[] byteValues();
+        char charValue();
+        char[] charValues();
+        double doubleValue();
+        double[] doubleValues();
+        float floatValue();
+        float[] floatValues();
+        int intValue();
+        int[] intValues();
+        long longValue();
+        long[] longValues();
+        NestAnnotation nest();
+        NestAnnotation[] nests();
+        short shortValue();
+        short[] shortValues();
+        Stooge stooge();
+        Stooge[] stooges();
+        String string();
+        String[] strings();
+        Class<?> type();
+        Class<?>[] types();
+    }
+
+    @Retention(RetentionPolicy.RUNTIME)
+    @Target({ElementType.METHOD})
+    public @interface TestMethodAnnotation {
+        final class None extends Throwable {
+
+            private static final long serialVersionUID = 1L;
+        }
+
+        Class<? extends Throwable> expected() default None.class;
+
+        long timeout() default 0L;
+    }
+
     @TestAnnotation(
             booleanValue = false,
             booleanValues = { false },
@@ -78,8 +144,8 @@ public class AnnotationUtilsTest {
                     longValues = { 0 },
                     shortValue = 0,
                     shortValues = { 0 },
-                    stooge = CURLY,
-                    stooges = { MOE, LARRY, SHEMP },
+                    stooge = Stooge.CURLY,
+                    stooges = { Stooge.MOE, Stooge.LARRY, Stooge.SHEMP },
                     string = "",
                     strings = { "" },
                     type = Object.class,
@@ -103,8 +169,8 @@ public class AnnotationUtilsTest {
                         longValues = { 0 },
                         shortValue = 0,
                         shortValues = { 0 },
-                        stooge = CURLY,
-                        stooges = { MOE, LARRY, SHEMP },
+                        stooge = Stooge.CURLY,
+                        stooges = { Stooge.MOE, Stooge.LARRY, Stooge.SHEMP },
                         string = "",
                         strings = { "" },
                         type = Object[].class,
@@ -113,8 +179,8 @@ public class AnnotationUtilsTest {
             },
             shortValue = 0,
             shortValues = { 0 },
-            stooge = SHEMP,
-            stooges = { MOE, LARRY, CURLY },
+            stooge = Stooge.SHEMP,
+            stooges = { Stooge.MOE, Stooge.LARRY, Stooge.CURLY },
             string = "",
             strings = { "" },
             type = Object.class,
@@ -154,8 +220,8 @@ public class AnnotationUtilsTest {
                     longValues = { 0 },
                     shortValue = 0,
                     shortValues = { 0 },
-                    stooge = CURLY,
-                    stooges = { MOE, LARRY, SHEMP },
+                    stooge = Stooge.CURLY,
+                    stooges = { Stooge.MOE, Stooge.LARRY, Stooge.SHEMP },
                     string = "",
                     strings = { "" },
                     type = Object.class,
@@ -179,8 +245,8 @@ public class AnnotationUtilsTest {
                         longValues = { 0 },
                         shortValue = 0,
                         shortValues = { 0 },
-                        stooge = CURLY,
-                        stooges = { MOE, LARRY, SHEMP },
+                        stooge = Stooge.CURLY,
+                        stooges = { Stooge.MOE, Stooge.LARRY, Stooge.SHEMP },
                         string = "",
                         strings = { "" },
                         type = Object[].class,
@@ -189,8 +255,8 @@ public class AnnotationUtilsTest {
             },
             shortValue = 0,
             shortValues = { 0 },
-            stooge = SHEMP,
-            stooges = { MOE, LARRY, CURLY },
+            stooge = Stooge.SHEMP,
+            stooges = { Stooge.MOE, Stooge.LARRY, Stooge.CURLY },
             string = "",
             strings = { "" },
             type = Object.class,
@@ -230,8 +296,8 @@ public class AnnotationUtilsTest {
                     longValues = { 0 },
                     shortValue = 0,
                     shortValues = { 0 },
-                    stooge = CURLY,
-                    stooges = { MOE, LARRY, SHEMP },
+                    stooge = Stooge.CURLY,
+                    stooges = { Stooge.MOE, Stooge.LARRY, Stooge.SHEMP },
                     string = "",
                     strings = { "" },
                     type = Object.class,
@@ -255,8 +321,8 @@ public class AnnotationUtilsTest {
                         longValues = { 0 },
                         shortValue = 0,
                         shortValues = { 0 },
-                        stooge = CURLY,
-                        stooges = { MOE, LARRY, SHEMP },
+                        stooge = Stooge.CURLY,
+                        stooges = { Stooge.MOE, Stooge.LARRY, Stooge.SHEMP },
                         string = "",
                         strings = { "" },
                         type = Object[].class,
@@ -280,8 +346,8 @@ public class AnnotationUtilsTest {
                         longValues = { 0 },
                         shortValue = 0,
                         shortValues = { 0 },
-                        stooge = CURLY,
-                        stooges = { MOE, LARRY, SHEMP },
+                        stooge = Stooge.CURLY,
+                        stooges = { Stooge.MOE, Stooge.LARRY, Stooge.SHEMP },
                         string = "",
                         strings = { "" },
                         type = Object[].class,
@@ -290,8 +356,8 @@ public class AnnotationUtilsTest {
             },
             shortValue = 0,
             shortValues = { 0 },
-            stooge = SHEMP,
-            stooges = { MOE, LARRY, CURLY },
+            stooge = Stooge.SHEMP,
+            stooges = { Stooge.MOE, Stooge.LARRY, Stooge.CURLY },
             string = "",
             strings = { "" },
             type = Object.class,
@@ -316,8 +382,8 @@ public class AnnotationUtilsTest {
             longValues = { 0 },
             shortValue = 0,
             shortValues = { 0 },
-            stooge = CURLY,
-            stooges = { MOE, LARRY, SHEMP },
+            stooge = Stooge.CURLY,
+            stooges = { Stooge.MOE, Stooge.LARRY, Stooge.SHEMP },
             string = "",
             strings = { "" },
             type = Object[].class,
@@ -325,76 +391,6 @@ public class AnnotationUtilsTest {
     )
     public Object dummy4;
 
-    @Target(FIELD)
-    @Retention(RUNTIME)
-    public @interface TestAnnotation {
-        String string();
-        String[] strings();
-        Class<?> type();
-        Class<?>[] types();
-        byte byteValue();
-        byte[] byteValues();
-        short shortValue();
-        short[] shortValues();
-        int intValue();
-        int[] intValues();
-        char charValue();
-        char[] charValues();
-        long longValue();
-        long[] longValues();
-        float floatValue();
-        float[] floatValues();
-        double doubleValue();
-        double[] doubleValues();
-        boolean booleanValue();
-        boolean[] booleanValues();
-        Stooge stooge();
-        Stooge[] stooges();
-        NestAnnotation nest();
-        NestAnnotation[] nests();
-    }
-
-    @Retention(RUNTIME)
-    public @interface NestAnnotation {
-        String string();
-        String[] strings();
-        Class<?> type();
-        Class<?>[] types();
-        byte byteValue();
-        byte[] byteValues();
-        short shortValue();
-        short[] shortValues();
-        int intValue();
-        int[] intValues();
-        char charValue();
-        char[] charValues();
-        long longValue();
-        long[] longValues();
-        float floatValue();
-        float[] floatValues();
-        double doubleValue();
-        double[] doubleValues();
-        boolean booleanValue();
-        boolean[] booleanValues();
-        Stooge stooge();
-        Stooge[] stooges();
-    }
-
-    @Retention(RetentionPolicy.RUNTIME)
-    @Target({ElementType.METHOD})
-    public @interface TestMethodAnnotation {
-        Class<? extends Throwable> expected() default None.class;
-
-        long timeout() default 0L;
-
-        class None extends Throwable {
-        }
-    }
-
-    public enum Stooge {
-        MOE, LARRY, CURLY, JOE, SHEMP
-    }
-
     private Field field1;
     private Field field2;
     private Field field3;
@@ -408,54 +404,21 @@ public class AnnotationUtilsTest {
         field4 = getClass().getDeclaredField("dummy4");
     }
 
-    @Test
-    public void testEquivalence() {
-        assertTrue(AnnotationUtils.equals(field1.getAnnotation(TestAnnotation.class), field2.getAnnotation(TestAnnotation.class)));
-        assertTrue(AnnotationUtils.equals(field2.getAnnotation(TestAnnotation.class), field1.getAnnotation(TestAnnotation.class)));
-    }
-
-    @Test
-    public void testSameInstance() {
-        assertTrue(AnnotationUtils.equals(field1.getAnnotation(TestAnnotation.class), field1.getAnnotation(TestAnnotation.class)));
-    }
-
-    @Test
-    public void testNonEquivalentAnnotationsOfSameType() {
-        assertFalse(AnnotationUtils.equals(field1.getAnnotation(TestAnnotation.class), field3.getAnnotation(TestAnnotation.class)));
-        assertFalse(AnnotationUtils.equals(field3.getAnnotation(TestAnnotation.class), field1.getAnnotation(TestAnnotation.class)));
-    }
-
     @Test
     public void testAnnotationsOfDifferingTypes() {
         assertFalse(AnnotationUtils.equals(field1.getAnnotation(TestAnnotation.class), field4.getAnnotation(NestAnnotation.class)));
         assertFalse(AnnotationUtils.equals(field4.getAnnotation(NestAnnotation.class), field1.getAnnotation(TestAnnotation.class)));
     }
 
-    @Test
-    public void testOneArgNull() {
-        assertFalse(AnnotationUtils.equals(field1.getAnnotation(TestAnnotation.class), null));
-        assertFalse(AnnotationUtils.equals(null, field1.getAnnotation(TestAnnotation.class)));
-    }
-
     @Test
     public void testBothArgsNull() {
         assertTrue(AnnotationUtils.equals(null, null));
     }
 
     @Test
-    public void testIsValidAnnotationMemberType() {
-        for (final Class<?> type : new Class[] { byte.class, short.class, int.class, char.class,
-                long.class, float.class, double.class, boolean.class, String.class, Class.class,
-                NestAnnotation.class, TestAnnotation.class, Stooge.class, ElementType.class }) {
-            assertTrue(AnnotationUtils.isValidAnnotationMemberType(type));
-            assertTrue(AnnotationUtils.isValidAnnotationMemberType(Array.newInstance(type, 0)
-                    .getClass()));
-        }
-        for (final Class<?> type : new Class[] { Object.class, Map.class, Collection.class }) {
-            assertFalse(AnnotationUtils.isValidAnnotationMemberType(type));
-            assertFalse(AnnotationUtils.isValidAnnotationMemberType(Array.newInstance(type, 0)
-                    .getClass()));
-        }
+    public void testEquivalence() {
+        assertTrue(AnnotationUtils.equals(field1.getAnnotation(TestAnnotation.class), field2.getAnnotation(TestAnnotation.class)));
+        assertTrue(AnnotationUtils.equals(field2.getAnnotation(TestAnnotation.class), field1.getAnnotation(TestAnnotation.class)));
     }
 
     @Test
@@ -507,6 +470,39 @@ public class AnnotationUtilsTest {
         });
     }
 
+    @Test
+    public void testIsValidAnnotationMemberType() {
+        for (final Class<?> type : new Class[] { byte.class, short.class, int.class, char.class,
+                long.class, float.class, double.class, boolean.class, String.class, Class.class,
+                NestAnnotation.class, TestAnnotation.class, Stooge.class, ElementType.class }) {
+            assertTrue(AnnotationUtils.isValidAnnotationMemberType(type));
+            assertTrue(AnnotationUtils.isValidAnnotationMemberType(Array.newInstance(type, 0)
+                    .getClass()));
+        }
+        for (final Class<?> type : new Class[] { Object.class, Map.class, Collection.class }) {
+            assertFalse(AnnotationUtils.isValidAnnotationMemberType(type));
+            assertFalse(AnnotationUtils.isValidAnnotationMemberType(Array.newInstance(type, 0)
+                    .getClass()));
+        }
+    }
+
+    @Test
+    public void testNonEquivalentAnnotationsOfSameType() {
+        assertFalse(AnnotationUtils.equals(field1.getAnnotation(TestAnnotation.class), field3.getAnnotation(TestAnnotation.class)));
+        assertFalse(AnnotationUtils.equals(field3.getAnnotation(TestAnnotation.class), field1.getAnnotation(TestAnnotation.class)));
+    }
+
+    @Test
+    public void testOneArgNull() {
+        assertFalse(AnnotationUtils.equals(field1.getAnnotation(TestAnnotation.class), null));
+        assertFalse(AnnotationUtils.equals(null, field1.getAnnotation(TestAnnotation.class)));
+    }
+
+    @Test
+    public void testSameInstance() {
+        assertTrue(AnnotationUtils.equals(field1.getAnnotation(TestAnnotation.class), field1.getAnnotation(TestAnnotation.class)));
+    }
+
     @Test
     @TestMethodAnnotation(timeout = 666000)
     public void testToString() {
