@@ -24,7 +24,7 @@ import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.Test;
 
 /**
- * Unit tests {@link org.apache.commons.lang3.StringUtils} - Trim/Strip methods
+ * Tests {@link StringUtils} Trim/Strip methods.
  */
 public class StringUtilsTrimStripTest extends AbstractLangTest {
     private static final String FOO = "foo";
@@ -36,7 +36,7 @@ public class StringUtilsTrimStripTest extends AbstractLangTest {
         assertEquals("", StringUtils.strip("        "));
         assertEquals("abc", StringUtils.strip("  abc  "));
         assertEquals(StringUtilsTest.NON_WHITESPACE,
-            StringUtils.strip(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE));
+                StringUtils.strip(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE));
     }
 
     @Test
@@ -47,7 +47,7 @@ public class StringUtilsTrimStripTest extends AbstractLangTest {
         assertEquals("", StringUtils.strip("        ", null));
         assertEquals("abc", StringUtils.strip("  abc  ", null));
         assertEquals(StringUtilsTest.NON_WHITESPACE,
-            StringUtils.strip(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE, null));
+                StringUtils.strip(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE, null));
 
         // "" strip
         assertNull(StringUtils.strip(null, ""));
@@ -76,42 +76,62 @@ public class StringUtilsTrimStripTest extends AbstractLangTest {
         final String cue = "\u00C7\u00FA\u00EA";
         assertEquals("Cue", StringUtils.stripAccents(cue), "Failed to strip accents from " + cue);
 
-        final String lots = "\u00C0\u00C1\u00C2\u00C3\u00C4\u00C5\u00C7\u00C8\u00C9" +
-                      "\u00CA\u00CB\u00CC\u00CD\u00CE\u00CF\u00D1\u00D2\u00D3" +
-                      "\u00D4\u00D5\u00D6\u00D9\u00DA\u00DB\u00DC\u00DD";
-        assertEquals("AAAAAACEEEEIIIINOOOOOUUUUY",
-                StringUtils.stripAccents(lots),
-                "Failed to strip accents from " + lots);
+        final String lots = "\u00C0\u00C1\u00C2\u00C3\u00C4\u00C5\u00C7\u00C8\u00C9\u00CA\u00CB\u00CC\u00CD\u00CE\u00CF\u00D1\u00D2\u00D3"
+                + "\u00D4\u00D5\u00D6\u00D9\u00DA\u00DB\u00DC\u00DD";
+        assertEquals("AAAAAACEEEEIIIINOOOOOUUUUY", StringUtils.stripAccents(lots), "Failed to strip accents from " + lots);
 
         assertNull(StringUtils.stripAccents(null), "Failed null safety");
         assertEquals("", StringUtils.stripAccents(""), "Failed empty String");
         assertEquals("control", StringUtils.stripAccents("control"), "Failed to handle non-accented text");
         assertEquals("eclair", StringUtils.stripAccents("\u00E9clair"), "Failed to handle easy example");
-        assertEquals("ALOSZZCN aloszzcn", StringUtils.stripAccents("\u0104\u0141\u00D3\u015A\u017B\u0179\u0106\u0143 "
-                + "\u0105\u0142\u00F3\u015B\u017C\u017A\u0107\u0144"));
+        assertEquals("ALOSZZCND aloszzcnd",
+                StringUtils.stripAccents("\u0104\u0141\u00D3\u015A\u017B\u0179\u0106\u0143\u0110 \u0105\u0142\u00F3\u015B\u017C\u017A\u0107\u0144\u0111"));
+        assertEquals("The cafe\u2019s pinata gave me deja vu.", StringUtils.stripAccents("The caf\u00e9\u2019s pi\u00f1ata gave me d\u00e9j\u00e0 vu."),
+                "Failed to handle accented text");
+        assertEquals("fluid quest", StringUtils.stripAccents("\ufb02uid que\ufb06"), "Failed to handle ligatures");
+        assertEquals("a b c 1 2 3", StringUtils.stripAccents("\u1d43 \u1d47 \u1d9c \u00b9 \u00b2 \u00b3"), "Failed to handle superscript text");
+        assertEquals("math italic",
+                StringUtils.stripAccents("\uD835\uDC5A\uD835\uDC4E\uD835\uDC61\u210E \uD835\uDC56\uD835\uDC61\uD835\uDC4E\uD835\uDC59\uD835\uDC56\uD835\uDC50"),
+                "Failed to handle UTF32 example");
+        assertEquals("\uD83D\uDF01 \uD83D\uDF02 \uD83D\uDF03 \uD83D\uDF04", StringUtils.stripAccents("\uD83D\uDF01 \uD83D\uDF02 \uD83D\uDF03 \uD83D\uDF04"),
+                "Failed to handle non-accented text");
     }
 
     @Test
     @Disabled
     public void testStripAccents_Korean() {
         // LANG-1655
-        final String input = "잊지마 넌 흐린 어둠사이 왼손으로 그린 별 하나";
-        assertEquals(input, StringUtils.stripAccents(input), "Failed to handle non-accented text");
+        final String input = "\uC78A\uC9C0\uB9C8 \uB10C \uD750\uB9B0 \uC5B4\uB460\uC0AC\uC774 \uC67C\uC190\uC73C\uB85C \uADF8\uB9B0 \uBCC4 \uD558\uB098";
+        assertEquals(input, StringUtils.stripAccents(input), "Failed to handle Korean text");
+    }
 
+    @Test
+    public void testStripAccentsIWithBar() {
+        assertEquals("I i I i I", StringUtils.stripAccents("\u0197 \u0268 \u1D7B \u1DA4 \u1DA7"));
+    }
+
+    @Test
+    public void testStripAccentsTWithStroke() {
+        assertEquals("T t", StringUtils.stripAccents("\u0166 \u0167"));
+    }
+
+    @Test
+    public void testStripAccentsUWithBar() {
+        assertEquals("U u U u", StringUtils.stripAccents("\u0244 \u0289 \u1D7E \u1DB6"));
     }
 
     @Test
     public void testStripAll() {
         // test stripAll method, merely an array version of the above strip
         final String[] empty = {};
-        final String[] fooSpace = { "  "+FOO+"  ", "  "+FOO, FOO+"  " };
-        final String[] fooDots = { ".."+FOO+"..", ".."+FOO, FOO+".." };
+        final String[] fooSpace = { "  " + FOO + "  ", "  " + FOO, FOO + "  " };
+        final String[] fooDots = { ".." + FOO + "..", ".." + FOO, FOO + ".." };
         final String[] foo = { FOO, FOO, FOO };
 
         assertNull(StringUtils.stripAll((String[]) null));
         // Additional varargs tests
         assertArrayEquals(empty, StringUtils.stripAll()); // empty array
-        assertArrayEquals(new String[]{null}, StringUtils.stripAll((String) null)); // == new String[]{null}
+        assertArrayEquals(new String[] { null }, StringUtils.stripAll((String) null)); // == new String[]{null}
 
         assertArrayEquals(empty, StringUtils.stripAll(empty));
         assertArrayEquals(foo, StringUtils.stripAll(fooSpace));
@@ -129,7 +149,7 @@ public class StringUtilsTrimStripTest extends AbstractLangTest {
         assertEquals("", StringUtils.stripEnd("        ", null));
         assertEquals("  abc", StringUtils.stripEnd("  abc  ", null));
         assertEquals(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE,
-            StringUtils.stripEnd(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE, null));
+                StringUtils.stripEnd(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE, null));
 
         // "" stripEnd
         assertNull(StringUtils.stripEnd(null, ""));
@@ -161,7 +181,7 @@ public class StringUtilsTrimStripTest extends AbstractLangTest {
         assertEquals("", StringUtils.stripStart("        ", null));
         assertEquals("abc  ", StringUtils.stripStart("  abc  ", null));
         assertEquals(StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE,
-            StringUtils.stripStart(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE, null));
+                StringUtils.stripStart(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE, null));
 
         // "" stripStart
         assertNull(StringUtils.stripStart(null, ""));
@@ -193,7 +213,7 @@ public class StringUtilsTrimStripTest extends AbstractLangTest {
         assertEquals("", StringUtils.stripToEmpty(StringUtilsTest.WHITESPACE));
         assertEquals("ab c", StringUtils.stripToEmpty("  ab c  "));
         assertEquals(StringUtilsTest.NON_WHITESPACE,
-            StringUtils.stripToEmpty(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE));
+                StringUtils.stripToEmpty(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE));
     }
 
     @Test
@@ -204,7 +224,7 @@ public class StringUtilsTrimStripTest extends AbstractLangTest {
         assertNull(StringUtils.stripToNull(StringUtilsTest.WHITESPACE));
         assertEquals("ab c", StringUtils.stripToNull("  ab c  "));
         assertEquals(StringUtilsTest.NON_WHITESPACE,
-            StringUtils.stripToNull(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE));
+                StringUtils.stripToNull(StringUtilsTest.WHITESPACE + StringUtilsTest.NON_WHITESPACE + StringUtilsTest.WHITESPACE));
     }
 
     @Test
