@@ -24,61 +24,100 @@ import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertNotSame;
 import static org.junit.jupiter.api.Assertions.assertSame;
 import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
+import java.util.List;
 
 import org.apache.commons.lang3.AbstractLangTest;
 import org.apache.commons.lang3.ArrayUtils;
 import org.hamcrest.Matcher;
 import org.junit.jupiter.api.Test;
 
-
 /**
  * Unit tests {@link DiffBuilder}.
  */
 public class DiffBuilderTest extends AbstractLangTest {
 
+
+    /**
+     * Test fixture.
+     */
+    private static class NestedTypeTestClass implements Diffable<NestedTypeTestClass> {
+
+        private final ToStringStyle style = SHORT_STYLE;
+        private boolean booleanField = true;
+
+        @Override
+        public DiffResult<NestedTypeTestClass> diff(final NestedTypeTestClass obj) {
+            // @formatter:off
+            return new DiffBuilder<>(this, obj, style)
+                    .append("boolean", booleanField, obj.booleanField)
+                    .build();
+            // @formatter:on
+        }
+
+        @Override
+        public boolean equals(final Object obj) {
+            return EqualsBuilder.reflectionEquals(this, obj, false);
+        }
+
+        @Override
+        public int hashCode() {
+            return HashCodeBuilder.reflectionHashCode(this, false);
+        }
+    }
+
+    /**
+     * Test fixture.
+     */
     private static final class TypeTestClass implements Diffable<TypeTestClass> {
+
         private ToStringStyle style = SHORT_STYLE;
         private boolean booleanField = true;
-        private boolean[] booleanArrayField = {true};
+        private boolean[] booleanArrayField = { true };
         private byte byteField = (byte) 0xFF;
-        private byte[] byteArrayField = {(byte) 0xFF};
+        private byte[] byteArrayField = { (byte) 0xFF };
         private char charField = 'a';
-        private char[] charArrayField = {'a'};
+        private char[] charArrayField = { 'a' };
         private double doubleField = 1.0;
-        private double[] doubleArrayField = {1.0};
+        private double[] doubleArrayField = { 1.0 };
         private float floatField = 1.0f;
-        private float[] floatArrayField = {1.0f};
+        private float[] floatArrayField = { 1.0f };
         private int intField = 1;
-        private int[] intArrayField = {1};
+        private int[] intArrayField = { 1 };
         private long longField = 1L;
-        private long[] longArrayField = {1L};
+        private long[] longArrayField = { 1L };
         private short shortField = 1;
-        private short[] shortArrayField = {1};
+        private short[] shortArrayField = { 1 };
         private Object objectField;
-        private Object[] objectArrayField = {null};
+        private Object[] objectArrayField = { null };
+        private final NestedTypeTestClass nestedDiffableField = new NestedTypeTestClass();
 
         @Override
         public DiffResult<TypeTestClass> diff(final TypeTestClass obj) {
+            // @formatter:off
             return new DiffBuilder<>(this, obj, style)
-                .append("boolean", booleanField, obj.booleanField)
-                .append("booleanArray", booleanArrayField, obj.booleanArrayField)
-                .append("byte", byteField, obj.byteField)
-                .append("byteArray", byteArrayField, obj.byteArrayField)
-                .append("char", charField, obj.charField)
-                .append("charArray", charArrayField, obj.charArrayField)
-                .append("double", doubleField, obj.doubleField)
-                .append("doubleArray", doubleArrayField, obj.doubleArrayField)
-                .append("float", floatField, obj.floatField)
-                .append("floatArray", floatArrayField, obj.floatArrayField)
-                .append("int", intField, obj.intField)
-                .append("intArray", intArrayField, obj.intArrayField)
-                .append("long", longField, obj.longField)
-                .append("longArray", longArrayField, obj.longArrayField)
-                .append("short", shortField, obj.shortField)
-                .append("shortArray", shortArrayField, obj.shortArrayField)
-                .append("objectField", objectField, obj.objectField)
-                .append("objectArrayField", objectArrayField, obj.objectArrayField)
-                .build();
+                    .append("boolean", booleanField, obj.booleanField)
+                    .append("booleanArray", booleanArrayField, obj.booleanArrayField)
+                    .append("byte", byteField, obj.byteField)
+                    .append("byteArray", byteArrayField, obj.byteArrayField)
+                    .append("char", charField, obj.charField)
+                    .append("charArray", charArrayField, obj.charArrayField)
+                    .append("double", doubleField, obj.doubleField)
+                    .append("doubleArray", doubleArrayField, obj.doubleArrayField)
+                    .append("float", floatField, obj.floatField)
+                    .append("floatArray", floatArrayField, obj.floatArrayField)
+                    .append("int", intField, obj.intField)
+                    .append("intArray", intArrayField, obj.intArrayField)
+                    .append("long", longField, obj.longField)
+                    .append("longArray", longArrayField, obj.longArrayField)
+                    .append("short", shortField, obj.shortField)
+                    .append("shortArray", shortArrayField, obj.shortArrayField)
+                    .append("objectField", objectField, obj.objectField)
+                    .append("objectArrayField", objectArrayField, obj.objectArrayField)
+                    .append("nestedDiffableField", nestedDiffableField.diff(obj.nestedDiffableField))
+                    .build();
+            // @formatter:on
         }
 
         @Override
@@ -102,7 +141,7 @@ public class DiffBuilderTest extends AbstractLangTest {
         final DiffResult<TypeTestClass> list = class1.diff(class2);
         assertEquals(1, list.getNumberOfDiffs());
         final Diff<?> diff = list.getDiffs().get(0);
-        assertEquals(Boolean.class, diff.getType());
+        assertEquals(Boolean.class, diff.getType(), () -> diff.getType().getClass().toString());
         assertEquals(Boolean.TRUE, diff.getLeft());
         assertEquals(Boolean.FALSE, diff.getRight());
     }
@@ -111,14 +150,12 @@ public class DiffBuilderTest extends AbstractLangTest {
     public void testBooleanArray() {
         final TypeTestClass class1 = new TypeTestClass();
         final TypeTestClass class2 = new TypeTestClass();
-        class2.booleanArrayField = new boolean[] {false, false};
+        class2.booleanArrayField = new boolean[] { false, false };
         final DiffResult<TypeTestClass> list = class1.diff(class2);
         assertEquals(1, list.getNumberOfDiffs());
         final Diff<?> diff = list.getDiffs().get(0);
-        assertArrayEquals(ArrayUtils.toObject(class1.booleanArrayField),
-                (Object[]) diff.getLeft());
-        assertArrayEquals(ArrayUtils.toObject(class2.booleanArrayField),
-                (Object[]) diff.getRight());
+        assertArrayEquals(ArrayUtils.toObject(class1.booleanArrayField), (Object[]) diff.getLeft());
+        assertArrayEquals(ArrayUtils.toObject(class2.booleanArrayField), (Object[]) diff.getRight());
     }
 
     @Test
@@ -129,6 +166,7 @@ public class DiffBuilderTest extends AbstractLangTest {
         final DiffResult<TypeTestClass> list = class1.diff(class2);
         assertEquals(1, list.getNumberOfDiffs());
         final Diff<?> diff = list.getDiffs().get(0);
+        assertEquals(Byte.class, diff.getType(), () -> diff.getType().getClass().toString());
         assertEquals(Byte.valueOf(class1.byteField), diff.getLeft());
         assertEquals(Byte.valueOf(class2.byteField), diff.getRight());
     }
@@ -137,30 +175,47 @@ public class DiffBuilderTest extends AbstractLangTest {
     public void testByteArray() {
         final TypeTestClass class1 = new TypeTestClass();
         final TypeTestClass class2 = new TypeTestClass();
-        class2.byteArrayField= new byte[] {0x01, 0x02};
+        class2.byteArrayField = new byte[] { 0x01, 0x02 };
         final DiffResult<TypeTestClass> list = class1.diff(class2);
         assertEquals(1, list.getNumberOfDiffs());
         final Diff<?> diff = list.getDiffs().get(0);
-        assertArrayEquals(ArrayUtils.toObject(class1.byteArrayField),
-                (Object[]) diff.getLeft());
-        assertArrayEquals(ArrayUtils.toObject(class2.byteArrayField),
-                (Object[]) diff.getRight());
+        assertArrayEquals(ArrayUtils.toObject(class1.byteArrayField), (Object[]) diff.getLeft());
+        assertArrayEquals(ArrayUtils.toObject(class2.byteArrayField), (Object[]) diff.getRight());
     }
 
     @Test
-    public void testByteArrayEqualAsObject() {
-        final DiffResult<String> list = new DiffBuilder<>("String1", "String2", SHORT_STYLE)
-            .append("foo", new boolean[] {false}, new boolean[] {false})
-            .append("foo", new byte[] {0x01}, new byte[] {0x01})
-            .append("foo", new char[] {'a'}, new char[] {'a'})
-            .append("foo", new double[] {1.0}, new double[] {1.0})
-            .append("foo", new float[] {1.0F}, new float[] {1.0F})
-            .append("foo", new int[] {1}, new int[] {1})
-            .append("foo", new long[] {1L}, new long[] {1L})
-            .append("foo", new short[] {1}, new short[] {1})
-            .append("foo", new Object[] {1, "two"}, new Object[] {1, "two"})
-            .build();
+    public void testByteArrayEqualAsObject1() {
+        // @formatter:off
+        final DiffResult<String> list = DiffBuilder.<String>builder().setLeft("String1").setRight("String2").setStyle(SHORT_STYLE).build()
+                .append("foo", new boolean[] { false }, new boolean[] { false })
+                .append("foo", new byte[] { 0x01 }, new byte[] { 0x01 })
+                .append("foo", new char[] { 'a' }, new char[] { 'a' })
+                .append("foo", new double[] { 1.0 }, new double[] { 1.0 })
+                .append("foo", new float[] { 1.0F }, new float[] { 1.0F })
+                .append("foo", new int[] { 1 }, new int[] { 1 })
+                .append("foo", new long[] { 1L }, new long[] { 1L })
+                .append("foo", new short[] { 1 }, new short[] { 1 })
+                .append("foo", new Object[] { 1, "two" }, new Object[] { 1, "two" })
+                .build();
+        // @formatter:on
+        assertEquals(0, list.getNumberOfDiffs());
+    }
 
+    @Test
+    public void testByteArrayEqualAsObjectDeprecated() {
+        // @formatter:off
+        final DiffResult<String> list = new DiffBuilder<>("String1", "String2", SHORT_STYLE)
+                .append("foo", new boolean[] { false }, new boolean[] { false })
+                .append("foo", new byte[] { 0x01 }, new byte[] { 0x01 })
+                .append("foo", new char[] { 'a' }, new char[] { 'a' })
+                .append("foo", new double[] { 1.0 }, new double[] { 1.0 })
+                .append("foo", new float[] { 1.0F }, new float[] { 1.0F })
+                .append("foo", new int[] { 1 }, new int[] { 1 })
+                .append("foo", new long[] { 1L }, new long[] { 1L })
+                .append("foo", new short[] { 1 }, new short[] { 1 })
+                .append("foo", new Object[] { 1, "two" }, new Object[] { 1, "two" })
+                .build();
+        // @formatter:on
         assertEquals(0, list.getNumberOfDiffs());
     }
 
@@ -180,14 +235,12 @@ public class DiffBuilderTest extends AbstractLangTest {
     public void testCharArray() {
         final TypeTestClass class1 = new TypeTestClass();
         final TypeTestClass class2 = new TypeTestClass();
-        class2.charArrayField = new char[] {'f', 'o', 'o'};
+        class2.charArrayField = new char[] { 'f', 'o', 'o' };
         final DiffResult<TypeTestClass> list = class1.diff(class2);
         assertEquals(1, list.getNumberOfDiffs());
         final Diff<?> diff = list.getDiffs().get(0);
-        assertArrayEquals(ArrayUtils.toObject(class1.charArrayField),
-                (Object[]) diff.getLeft());
-        assertArrayEquals(ArrayUtils.toObject(class2.charArrayField),
-                (Object[]) diff.getRight());
+        assertArrayEquals(ArrayUtils.toObject(class1.charArrayField), (Object[]) diff.getLeft());
+        assertArrayEquals(ArrayUtils.toObject(class2.charArrayField), (Object[]) diff.getRight());
     }
 
     @Test
@@ -196,13 +249,21 @@ public class DiffBuilderTest extends AbstractLangTest {
         final TypeTestClass class2 = new TypeTestClass();
         class2.intField = 2;
 
-        final DiffResult<TypeTestClass> list = new DiffBuilder<>(class1, class2, SHORT_STYLE)
-            .append("prop1", class1.diff(class2))
-            .build();
+        final DiffResult<TypeTestClass> list = new DiffBuilder<>(class1, class2, SHORT_STYLE).append("prop1", class1.diff(class2)).build();
         assertEquals(1, list.getNumberOfDiffs());
         assertEquals("prop1.int", list.getDiffs().get(0).getFieldName());
     }
 
+    @Test
+    public void testDiffResultEquals() {
+        final TypeTestClass class1 = new TypeTestClass();
+        class1.intField = 2;
+
+        final DiffResult<TypeTestClass> list = new DiffBuilder<>(class1, class1, SHORT_STYLE).append("prop1", class1.diff(class1)).build();
+        assertEquals(0, list.getNumberOfDiffs());
+        assertTrue(list.getDiffs().isEmpty());
+    }
+
     @Test
     public void testDouble() {
         final TypeTestClass class1 = new TypeTestClass();
@@ -219,14 +280,12 @@ public class DiffBuilderTest extends AbstractLangTest {
     public void testDoubleArray() {
         final TypeTestClass class1 = new TypeTestClass();
         final TypeTestClass class2 = new TypeTestClass();
-        class2.doubleArrayField = new double[] {3.0, 2.9, 2.8};
+        class2.doubleArrayField = new double[] { 3.0, 2.9, 2.8 };
         final DiffResult<TypeTestClass> list = class1.diff(class2);
         assertEquals(1, list.getNumberOfDiffs());
         final Diff<?> diff = list.getDiffs().get(0);
-        assertArrayEquals(ArrayUtils.toObject(class1.doubleArrayField),
-                (Object[]) diff.getLeft());
-        assertArrayEquals(ArrayUtils.toObject(class2.doubleArrayField),
-                (Object[]) diff.getRight());
+        assertArrayEquals(ArrayUtils.toObject(class1.doubleArrayField), (Object[]) diff.getLeft());
+        assertArrayEquals(ArrayUtils.toObject(class2.doubleArrayField), (Object[]) diff.getRight());
     }
 
     @Test
@@ -245,14 +304,12 @@ public class DiffBuilderTest extends AbstractLangTest {
     public void testFloatArray() {
         final TypeTestClass class1 = new TypeTestClass();
         final TypeTestClass class2 = new TypeTestClass();
-        class2.floatArrayField = new float[] {3.0F, 2.9F, 2.8F};
+        class2.floatArrayField = new float[] { 3.0F, 2.9F, 2.8F };
         final DiffResult<TypeTestClass> list = class1.diff(class2);
         assertEquals(1, list.getNumberOfDiffs());
         final Diff<?> diff = list.getDiffs().get(0);
-        assertArrayEquals(ArrayUtils.toObject(class1.floatArrayField),
-                (Object[]) diff.getLeft());
-        assertArrayEquals(ArrayUtils.toObject(class2.floatArrayField),
-                (Object[]) diff.getRight());
+        assertArrayEquals(ArrayUtils.toObject(class1.floatArrayField), (Object[]) diff.getLeft());
+        assertArrayEquals(ArrayUtils.toObject(class2.floatArrayField), (Object[]) diff.getRight());
     }
 
     @Test
@@ -271,14 +328,12 @@ public class DiffBuilderTest extends AbstractLangTest {
     public void testIntArray() {
         final TypeTestClass class1 = new TypeTestClass();
         final TypeTestClass class2 = new TypeTestClass();
-        class2.intArrayField = new int[] {3, 2, 1};
+        class2.intArrayField = new int[] { 3, 2, 1 };
         final DiffResult<TypeTestClass> list = class1.diff(class2);
         assertEquals(1, list.getNumberOfDiffs());
         final Diff<?> diff = list.getDiffs().get(0);
-        assertArrayEquals(ArrayUtils.toObject(class1.intArrayField),
-                (Object[]) diff.getLeft());
-        assertArrayEquals(ArrayUtils.toObject(class2.intArrayField),
-                (Object[]) diff.getRight());
+        assertArrayEquals(ArrayUtils.toObject(class1.intArrayField), (Object[]) diff.getLeft());
+        assertArrayEquals(ArrayUtils.toObject(class2.intArrayField), (Object[]) diff.getRight());
     }
 
     @Test
@@ -297,14 +352,66 @@ public class DiffBuilderTest extends AbstractLangTest {
     public void testLongArray() {
         final TypeTestClass class1 = new TypeTestClass();
         final TypeTestClass class2 = new TypeTestClass();
-        class2.longArrayField = new long[] {3L, 2L, 1L};
+        class2.longArrayField = new long[] { 3L, 2L, 1L };
         final DiffResult<TypeTestClass> list = class1.diff(class2);
         assertEquals(1, list.getNumberOfDiffs());
         final Diff<?> diff = list.getDiffs().get(0);
-        assertArrayEquals(ArrayUtils.toObject(class1.longArrayField),
-                (Object[]) diff.getLeft());
-        assertArrayEquals(ArrayUtils.toObject(class2.longArrayField),
-                (Object[]) diff.getRight());
+        assertArrayEquals(ArrayUtils.toObject(class1.longArrayField), (Object[]) diff.getLeft());
+        assertArrayEquals(ArrayUtils.toObject(class2.longArrayField), (Object[]) diff.getRight());
+    }
+
+    @Test
+    public void testNestedDiffableNo() {
+        final TypeTestClass class1 = new TypeTestClass();
+        final TypeTestClass class2 = new TypeTestClass();
+        final DiffResult<TypeTestClass> list = class1.diff(class2);
+        assertEquals(0, list.getNumberOfDiffs());
+        final List<Diff<?>> diff = list.getDiffs();
+        assertTrue(diff.isEmpty());
+    }
+
+    @Test
+    public void testNestedDiffableYesNestedNot() {
+        final TypeTestClass class1 = new TypeTestClass();
+        final TypeTestClass class2 = new TypeTestClass();
+        class2.intField = 9;
+        final DiffResult<TypeTestClass> list = class1.diff(class2);
+        assertEquals(1, list.getNumberOfDiffs());
+        final Diff<?> diff = list.getDiffs().get(0);
+        assertEquals(Integer.class, diff.getType());
+        assertEquals(1, diff.getLeft());
+        assertEquals(9, diff.getRight());
+    }
+
+    @Test
+    public void testNestedDiffableYesNestedOnly() {
+        final TypeTestClass class1 = new TypeTestClass();
+        final TypeTestClass class2 = new TypeTestClass();
+        class2.nestedDiffableField.booleanField = false;
+        final DiffResult<TypeTestClass> list = class1.diff(class2);
+        assertEquals(1, list.getNumberOfDiffs());
+        final Diff<?> diff = list.getDiffs().get(0);
+        assertEquals(Object.class, diff.getType());
+        assertEquals(Boolean.TRUE, diff.getLeft());
+        assertEquals(Boolean.FALSE, diff.getRight());
+    }
+
+    @Test
+    public void testNestedDiffableYesNestedYes() {
+        final TypeTestClass class1 = new TypeTestClass();
+        final TypeTestClass class2 = new TypeTestClass();
+        class2.intField = 9;
+        class2.nestedDiffableField.booleanField = false;
+        final DiffResult<TypeTestClass> list = class1.diff(class2);
+        assertEquals(2, list.getNumberOfDiffs());
+        final Diff<?> diff0 = list.getDiffs().get(0);
+        assertEquals(Integer.class, diff0.getType());
+        assertEquals(1, diff0.getLeft());
+        assertEquals(9, diff0.getRight());
+        final Diff<?> diff1 = list.getDiffs().get(1);
+        assertEquals(Object.class, diff1.getType());
+        assertEquals(Boolean.TRUE, diff1.getLeft());
+        assertEquals(Boolean.FALSE, diff1.getRight());
     }
 
     @Test
@@ -343,7 +450,7 @@ public class DiffBuilderTest extends AbstractLangTest {
     public void testObjectArray() {
         final TypeTestClass class1 = new TypeTestClass();
         final TypeTestClass class2 = new TypeTestClass();
-        class2.objectArrayField = new Object[] {"string", 1, 2};
+        class2.objectArrayField = new Object[] { "string", 1, 2 };
         final DiffResult<TypeTestClass> list = class1.diff(class2);
         assertEquals(1, list.getNumberOfDiffs());
         final Diff<?> diff = list.getDiffs().get(0);
@@ -355,8 +462,8 @@ public class DiffBuilderTest extends AbstractLangTest {
     public void testObjectArrayEqual() {
         final TypeTestClass class1 = new TypeTestClass();
         final TypeTestClass class2 = new TypeTestClass();
-        class1.objectArrayField = new Object[] {"string", 1, 2};
-        class2.objectArrayField = new Object[] {"string", 1, 2};
+        class1.objectArrayField = new Object[] { "string", 1, 2 };
+        class2.objectArrayField = new Object[] { "string", 1, 2 };
         final DiffResult<TypeTestClass> list = class1.diff(class2);
         assertEquals(0, list.getNumberOfDiffs());
     }
@@ -413,9 +520,7 @@ public class DiffBuilderTest extends AbstractLangTest {
     @Test
     public void testSameObjectIgnoresAppends() {
         final TypeTestClass testClass = new TypeTestClass();
-        final DiffResult<TypeTestClass> list = new DiffBuilder<>(testClass, testClass, SHORT_STYLE)
-            .append("ignored", false, true)
-            .build();
+        final DiffResult<TypeTestClass> list = new DiffBuilder<>(testClass, testClass, SHORT_STYLE).append("ignored", false, true).build();
         assertEquals(0, list.getNumberOfDiffs());
     }
 
@@ -435,23 +540,19 @@ public class DiffBuilderTest extends AbstractLangTest {
     public void testShortArray() {
         final TypeTestClass class1 = new TypeTestClass();
         final TypeTestClass class2 = new TypeTestClass();
-        class2.shortArrayField = new short[] {3, 2, 1};
+        class2.shortArrayField = new short[] { 3, 2, 1 };
         final DiffResult<TypeTestClass> list = class1.diff(class2);
         assertEquals(1, list.getNumberOfDiffs());
         final Diff<?> diff = list.getDiffs().get(0);
-        assertArrayEquals(ArrayUtils.toObject(class1.shortArrayField),
-                (Object[]) diff.getLeft());
-        assertArrayEquals(ArrayUtils.toObject(class2.shortArrayField),
-                (Object[]) diff.getRight());
+        assertArrayEquals(ArrayUtils.toObject(class1.shortArrayField), (Object[]) diff.getLeft());
+        assertArrayEquals(ArrayUtils.toObject(class2.shortArrayField), (Object[]) diff.getRight());
     }
 
     @Test
     public void testSimilarObjectIgnoresAppends() {
         final TypeTestClass testClass1 = new TypeTestClass();
         final TypeTestClass testClass2 = new TypeTestClass();
-        final DiffResult<TypeTestClass> list = new DiffBuilder<>(testClass1, testClass2, SHORT_STYLE)
-            .append("ignored", false, true)
-            .build();
+        final DiffResult<TypeTestClass> list = new DiffBuilder<>(testClass1, testClass2, SHORT_STYLE).append("ignored", false, true).build();
         assertEquals(0, list.getNumberOfDiffs());
     }
 
