@@ -18,9 +18,10 @@ package org.apache.commons.lang3.builder;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.junit.jupiter.api.Test;
 
-public class ReflectionToStringBuilderSummaryTest {
+public class ReflectionToStringBuilderSummaryTest extends AbstractLangTest {
 
     @SuppressWarnings("unused")
     private final String stringField = "string";
