@@ -21,6 +21,7 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 import java.util.Arrays;
 import java.util.Collections;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.apache.commons.lang3.builder.ToStringStyleTest.Person;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
@@ -29,7 +30,7 @@ import org.junit.jupiter.api.Test;
 /**
  * Unit tests {@link org.apache.commons.lang3.builder.SimpleToStringStyleTest}.
  */
-public class SimpleToStringStyleTest {
+public class SimpleToStringStyleTest extends AbstractLangTest {
 
     private final Integer base = Integer.valueOf(5);
 
@@ -43,13 +44,6 @@ public class SimpleToStringStyleTest {
         ToStringBuilder.setDefaultStyle(ToStringStyle.DEFAULT_STYLE);
     }
 
-    //----------------------------------------------------------------
-
-    @Test
-    public void testBlank() {
-        assertEquals("", new ToStringBuilder(base).toString());
-    }
-
     @Test
     public void testAppendSuper() {
         assertEquals("", new ToStringBuilder(base).appendSuper("").toString());
@@ -60,38 +54,6 @@ public class SimpleToStringStyleTest {
         assertEquals("hello", new ToStringBuilder(base).appendSuper(null).append("a", "hello").toString());
     }
 
-    @Test
-    public void testObject() {
-        final Integer i3 = Integer.valueOf(3);
-        final Integer i4 = Integer.valueOf(4);
-        assertEquals("<null>", new ToStringBuilder(base).append((Object) null).toString());
-        assertEquals("3", new ToStringBuilder(base).append(i3).toString());
-        assertEquals("<null>", new ToStringBuilder(base).append("a", (Object) null).toString());
-        assertEquals("3", new ToStringBuilder(base).append("a", i3).toString());
-        assertEquals("3,4", new ToStringBuilder(base).append("a", i3).append("b", i4).toString());
-        assertEquals("<Integer>", new ToStringBuilder(base).append("a", i3, false).toString());
-    }
-
-    @Test
-    public void testCollection() {
-        final Integer i3 = Integer.valueOf(3);
-        final Integer i4 = Integer.valueOf(4);
-        assertEquals("<size=0>", new ToStringBuilder(base).append("a", Collections.emptyList(), false).toString());
-        assertEquals("[]", new ToStringBuilder(base).append("a", Collections.emptyList(), true).toString());
-        assertEquals("<size=1>", new ToStringBuilder(base).append("a", Collections.singletonList(i3), false).toString());
-        assertEquals("[3]", new ToStringBuilder(base).append("a", Collections.singletonList(i3), true).toString());
-        assertEquals("<size=2>", new ToStringBuilder(base).append("a", Arrays.asList(i3, i4), false).toString());
-        assertEquals("[3, 4]", new ToStringBuilder(base).append("a", Arrays.asList(i3, i4), true).toString());
-    }
-
-    @Test
-    public void testMap() {
-        assertEquals("<size=0>", new ToStringBuilder(base).append("a", Collections.emptyMap(), false).toString());
-        assertEquals("{}", new ToStringBuilder(base).append("a", Collections.emptyMap(), true).toString());
-        assertEquals("<size=1>", new ToStringBuilder(base).append("a", Collections.singletonMap("k", "v"), false).toString());
-        assertEquals("{k=v}", new ToStringBuilder(base).append("a", Collections.singletonMap("k", "v"), true).toString());
-    }
-
     @Test
     public void testArray() {
         final Integer i3 = Integer.valueOf(3);
@@ -105,12 +67,20 @@ public class SimpleToStringStyleTest {
     }
 
     @Test
-    public void testPerson() {
-        final Person p = new Person();
-        p.name = "Jane Q. Public";
-        p.age = 47;
-        p.smoker = false;
-        assertEquals("Jane Q. Public,47,false", new ToStringBuilder(p).append("name", p.name).append("age", p.age).append("smoker", p.smoker).toString());
+    public void testBlank() {
+        assertEquals("", new ToStringBuilder(base).toString());
+    }
+
+    @Test
+    public void testCollection() {
+        final Integer i3 = Integer.valueOf(3);
+        final Integer i4 = Integer.valueOf(4);
+        assertEquals("<size=0>", new ToStringBuilder(base).append("a", Collections.emptyList(), false).toString());
+        assertEquals("[]", new ToStringBuilder(base).append("a", Collections.emptyList(), true).toString());
+        assertEquals("<size=1>", new ToStringBuilder(base).append("a", Collections.singletonList(i3), false).toString());
+        assertEquals("[3]", new ToStringBuilder(base).append("a", Collections.singletonList(i3), true).toString());
+        assertEquals("<size=2>", new ToStringBuilder(base).append("a", Arrays.asList(i3, i4), false).toString());
+        assertEquals("[3, 4]", new ToStringBuilder(base).append("a", Arrays.asList(i3, i4), true).toString());
     }
 
     @Test
@@ -120,19 +90,9 @@ public class SimpleToStringStyleTest {
         assertEquals("3,4", new ToStringBuilder(base).append("a", 3L).append("b", 4L).toString());
     }
 
-    @Test
-    public void testObjectArray() {
-        Object[] array = new Object[] {null, base, new int[] {3, 6}};
-        assertEquals("{<null>,5,{3,6}}", new ToStringBuilder(base).append(array).toString());
-        assertEquals("{<null>,5,{3,6}}", new ToStringBuilder(base).append((Object) array).toString());
-        array = null;
-        assertEquals("<null>", new ToStringBuilder(base).append(array).toString());
-        assertEquals("<null>", new ToStringBuilder(base).append((Object) array).toString());
-    }
-
     @Test
     public void testLongArray() {
-        long[] array = new long[] {1, 2, -3, 4};
+        long[] array = {1, 2, -3, 4};
         assertEquals("{1,2,-3,4}", new ToStringBuilder(base).append(array).toString());
         assertEquals("{1,2,-3,4}", new ToStringBuilder(base).append((Object) array).toString());
         array = null;
@@ -142,7 +102,7 @@ public class SimpleToStringStyleTest {
 
     @Test
     public void testLongArrayArray() {
-        long[][] array = new long[][] {{1, 2}, null, {5}};
+        long[][] array = {{1, 2}, null, {5}};
         assertEquals("{{1,2},<null>,{5}}", new ToStringBuilder(base).append(array).toString());
         assertEquals("{{1,2},<null>,{5}}", new ToStringBuilder(base).append((Object) array).toString());
         array = null;
@@ -150,4 +110,43 @@ public class SimpleToStringStyleTest {
         assertEquals("<null>", new ToStringBuilder(base).append((Object) array).toString());
     }
 
+    @Test
+    public void testMap() {
+        assertEquals("<size=0>", new ToStringBuilder(base).append("a", Collections.emptyMap(), false).toString());
+        assertEquals("{}", new ToStringBuilder(base).append("a", Collections.emptyMap(), true).toString());
+        assertEquals("<size=1>", new ToStringBuilder(base).append("a", Collections.singletonMap("k", "v"), false).toString());
+        assertEquals("{k=v}", new ToStringBuilder(base).append("a", Collections.singletonMap("k", "v"), true).toString());
+    }
+
+    @Test
+    public void testObject() {
+        final Integer i3 = Integer.valueOf(3);
+        final Integer i4 = Integer.valueOf(4);
+        assertEquals("<null>", new ToStringBuilder(base).append((Object) null).toString());
+        assertEquals("3", new ToStringBuilder(base).append(i3).toString());
+        assertEquals("<null>", new ToStringBuilder(base).append("a", (Object) null).toString());
+        assertEquals("3", new ToStringBuilder(base).append("a", i3).toString());
+        assertEquals("3,4", new ToStringBuilder(base).append("a", i3).append("b", i4).toString());
+        assertEquals("<Integer>", new ToStringBuilder(base).append("a", i3, false).toString());
+    }
+
+    @Test
+    public void testObjectArray() {
+        Object[] array = {null, base, new int[] {3, 6}};
+        assertEquals("{<null>,5,{3,6}}", new ToStringBuilder(base).append(array).toString());
+        assertEquals("{<null>,5,{3,6}}", new ToStringBuilder(base).append((Object) array).toString());
+        array = null;
+        assertEquals("<null>", new ToStringBuilder(base).append(array).toString());
+        assertEquals("<null>", new ToStringBuilder(base).append((Object) array).toString());
+    }
+
+    @Test
+    public void testPerson() {
+        final Person p = new Person();
+        p.name = "Jane Q. Public";
+        p.age = 47;
+        p.smoker = false;
+        assertEquals("Jane Q. Public,47,false", new ToStringBuilder(p).append("name", p.name).append("age", p.age).append("smoker", p.smoker).toString());
+    }
+
 }
