@@ -30,21 +30,14 @@ import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.easymock.EasyMock;
 import org.junit.jupiter.api.Test;
 
 /**
  * Test class for {@link ConcurrentUtils}.
  */
-public class ConcurrentUtilsTest {
-    /**
-     * Tests creating a ConcurrentException with a runtime exception as cause.
-     */
-    @Test
-    public void testConcurrentExceptionCauseUnchecked() {
-        assertThrows(IllegalArgumentException.class, () -> new ConcurrentException(new RuntimeException()));
-    }
-
+public class ConcurrentUtilsTest extends AbstractLangTest {
     /**
      * Tests creating a ConcurrentException with an error as cause.
      */
@@ -62,11 +55,11 @@ public class ConcurrentUtilsTest {
     }
 
     /**
-     * Tries to create a ConcurrentRuntimeException with a runtime as cause.
+     * Tests creating a ConcurrentException with a runtime exception as cause.
      */
     @Test
-    public void testConcurrentRuntimeExceptionCauseUnchecked() {
-        assertThrows(IllegalArgumentException.class, () -> new ConcurrentRuntimeException(new RuntimeException()));
+    public void testConcurrentExceptionCauseUnchecked() {
+        assertThrows(IllegalArgumentException.class, () -> new ConcurrentException(new RuntimeException()));
     }
 
     /**
@@ -86,277 +79,17 @@ public class ConcurrentUtilsTest {
     }
 
     /**
-     * Tests extractCause() for a null exception.
+     * Tries to create a ConcurrentRuntimeException with a runtime as cause.
      */
     @Test
-    public void testExtractCauseNull() {
-        assertNull(ConcurrentUtils.extractCause(null), "Non null result");
+    public void testConcurrentRuntimeExceptionCauseUnchecked() {
+        assertThrows(IllegalArgumentException.class, () -> new ConcurrentRuntimeException(new RuntimeException()));
     }
 
-    /**
-     * Tests extractCause() if the cause of the passed in exception is null.
-     */
-    @Test
-    public void testExtractCauseNullCause() {
-        assertNull(ConcurrentUtils.extractCause(new ExecutionException("Test", null)), "Non null result");
-    }
-
-    /**
-     * Tests extractCause() if the cause is an error.
-     */
-    @Test
-    public void testExtractCauseError() {
-        final Error err = new AssertionError("Test");
-        final AssertionError e =
-                assertThrows(AssertionError.class, () -> ConcurrentUtils.extractCause(new ExecutionException(err)));
-        assertEquals(err, e, "Wrong error");
-    }
-
-    /**
-     * Tests extractCause() if the cause is an unchecked exception.
-     */
-    @Test
-    public void testExtractCauseUncheckedException() {
-        final RuntimeException rex = new RuntimeException("Test");
-        assertThrows(RuntimeException.class, () -> ConcurrentUtils.extractCause(new ExecutionException(rex)));
-    }
-
-    /**
-     * Tests extractCause() if the cause is a checked exception.
-     */
-    @Test
-    public void testExtractCauseChecked() {
-        final Exception ex = new Exception("Test");
-        final ConcurrentException cex = ConcurrentUtils
-                .extractCause(new ExecutionException(ex));
-        assertSame(ex, cex.getCause(), "Wrong cause");
-    }
-
-    /**
-     * Tests extractCauseUnchecked() for a null exception.
-     */
-    @Test
-    public void testExtractCauseUncheckedNull() {
-        assertNull(ConcurrentUtils.extractCauseUnchecked(null), "Non null result");
-    }
-
-    /**
-     * Tests extractCauseUnchecked() if the cause of the passed in exception is null.
-     */
-    @Test
-    public void testExtractCauseUncheckedNullCause() {
-        assertNull(ConcurrentUtils.extractCauseUnchecked(new ExecutionException("Test", null)), "Non null result");
-    }
-
-    /**
-     * Tests extractCauseUnchecked() if the cause is an error.
-     */
-    @Test
-    public void testExtractCauseUncheckedError() {
-        final Error err = new AssertionError("Test");
-        final Error e = assertThrows(Error.class, () -> ConcurrentUtils.extractCauseUnchecked(new ExecutionException(err)));
-        assertEquals(err, e, "Wrong error");
-    }
-
-    /**
-     * Tests extractCauseUnchecked() if the cause is an unchecked exception.
-     */
-    @Test
-    public void testExtractCauseUncheckedUncheckedException() {
-        final RuntimeException rex = new RuntimeException("Test");
-        final RuntimeException r =
-                assertThrows(RuntimeException.class, () -> ConcurrentUtils.extractCauseUnchecked(new ExecutionException(rex)));
-        assertEquals(rex, r, "Wrong exception");
-    }
-
-    /**
-     * Tests extractCauseUnchecked() if the cause is a checked exception.
-     */
-    @Test
-    public void testExtractCauseUncheckedChecked() {
-        final Exception ex = new Exception("Test");
-        final ConcurrentRuntimeException cex = ConcurrentUtils
-                .extractCauseUnchecked(new ExecutionException(ex));
-        assertSame(ex, cex.getCause(), "Wrong cause");
-    }
-
-    /**
-     * Tests handleCause() if the cause is an error.
-     */
-    @Test
-    public void testHandleCauseError() {
-        final Error err = new AssertionError("Test");
-        final Error e = assertThrows(Error.class, () -> ConcurrentUtils.handleCause(new ExecutionException(err)));
-        assertEquals(err, e, "Wrong error");
-    }
-
-    /**
-     * Tests handleCause() if the cause is an unchecked exception.
-     */
-    @Test
-    public void testHandleCauseUncheckedException() {
-        final RuntimeException rex = new RuntimeException("Test");
-        final RuntimeException r =
-                assertThrows(RuntimeException.class, () -> ConcurrentUtils.handleCause(new ExecutionException(rex)));
-        assertEquals(rex, r, "Wrong exception");
-    }
-
-    /**
-     * Tests handleCause() if the cause is a checked exception.
-     */
-    @Test
-    public void testHandleCauseChecked() {
-        final Exception ex = new Exception("Test");
-        final ConcurrentException cex =
-                assertThrows(ConcurrentException.class, () -> ConcurrentUtils.handleCause(new ExecutionException(ex)));
-        assertEquals(ex, cex.getCause(), "Wrong cause");
-    }
-
-    /**
-     * Tests handleCause() for a null parameter or a null cause. In this case
-     * the method should do nothing. We can only test that no exception is
-     * thrown.
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
-     */
-    @Test
-    public void testHandleCauseNull() throws ConcurrentException {
-        ConcurrentUtils.handleCause(null);
-        ConcurrentUtils.handleCause(new ExecutionException("Test", null));
-    }
-
-    /**
-     * Tests handleCauseUnchecked() if the cause is an error.
-     */
-    @Test
-    public void testHandleCauseUncheckedError() {
-        final Error err = new AssertionError("Test");
-        final Error e = assertThrows(Error.class, () -> ConcurrentUtils.handleCauseUnchecked(new ExecutionException(err)));
-        assertEquals(err, e, "Wrong error");
-    }
-
-    /**
-     * Tests handleCauseUnchecked() if the cause is an unchecked exception.
-     */
-    @Test
-    public void testHandleCauseUncheckedUncheckedException() {
-        final RuntimeException rex = new RuntimeException("Test");
-        final RuntimeException r =
-                assertThrows(RuntimeException.class, () -> ConcurrentUtils.handleCauseUnchecked(new ExecutionException(rex)));
-        assertEquals(rex, r, "Wrong exception");
-    }
-
-    /**
-     * Tests handleCauseUnchecked() if the cause is a checked exception.
-     */
-    @Test
-    public void testHandleCauseUncheckedChecked() {
-        final Exception ex = new Exception("Test");
-        final ConcurrentRuntimeException crex =
-                assertThrows(ConcurrentRuntimeException.class, () -> ConcurrentUtils.handleCauseUnchecked(new ExecutionException(ex)));
-        assertEquals(ex, crex.getCause(), "Wrong cause");
-    }
-
-    /**
-     * Tests handleCauseUnchecked() for a null parameter or a null cause. In
-     * this case the method should do nothing. We can only test that no
-     * exception is thrown.
-     */
-    @Test
-    public void testHandleCauseUncheckedNull() {
-        ConcurrentUtils.handleCauseUnchecked(null);
-        ConcurrentUtils.handleCauseUnchecked(new ExecutionException("Test",
-                null));
-    }
-
-    //-----------------------------------------------------------------------
-    /**
-     * Tests initialize() for a null argument.
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
-     */
-    @Test
-    public void testInitializeNull() throws ConcurrentException {
-        assertNull(ConcurrentUtils.initialize(null), "Got a result");
-    }
-
-    /**
-     * Tests a successful initialize() operation.
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
-     */
-    @Test
-    public void testInitialize() throws ConcurrentException {
-        @SuppressWarnings("unchecked")
-        final
-        ConcurrentInitializer<Object> init = EasyMock
-                .createMock(ConcurrentInitializer.class);
-        final Object result = new Object();
-        EasyMock.expect(init.get()).andReturn(result);
-        EasyMock.replay(init);
-        assertSame(result, ConcurrentUtils.initialize(init), "Wrong result object");
-        EasyMock.verify(init);
-    }
-
-    /**
-     * Tests initializeUnchecked() for a null argument.
-     */
-    @Test
-    public void testInitializeUncheckedNull() {
-        assertNull(ConcurrentUtils.initializeUnchecked(null), "Got a result");
-    }
-
-    /**
-     * Tests creating ConcurrentRuntimeException with no arguments.
-     */
-    @Test
-    public void testUninitializedConcurrentRuntimeException() {
-        assertNotNull(new ConcurrentRuntimeException(), "Error creating empty ConcurrentRuntimeException");
-    }
-
-    /**
-     * Tests a successful initializeUnchecked() operation.
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
-     */
-    @Test
-    public void testInitializeUnchecked() throws ConcurrentException {
-        @SuppressWarnings("unchecked")
-        final
-        ConcurrentInitializer<Object> init = EasyMock
-                .createMock(ConcurrentInitializer.class);
-        final Object result = new Object();
-        EasyMock.expect(init.get()).andReturn(result);
-        EasyMock.replay(init);
-        assertSame(result, ConcurrentUtils.initializeUnchecked(init), "Wrong result object");
-        EasyMock.verify(init);
-    }
-
-    /**
-     * Tests whether exceptions are correctly handled by initializeUnchecked().
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
-     */
-    @Test
-    public void testInitializeUncheckedEx() throws ConcurrentException {
-        @SuppressWarnings("unchecked")
-        final
-        ConcurrentInitializer<Object> init = EasyMock
-                .createMock(ConcurrentInitializer.class);
-        final Exception cause = new Exception();
-        EasyMock.expect(init.get()).andThrow(new ConcurrentException(cause));
-        EasyMock.replay(init);
-        final ConcurrentRuntimeException crex =
-                assertThrows(ConcurrentRuntimeException.class, () -> ConcurrentUtils.initializeUnchecked(init));
-        assertSame(cause, crex.getCause(), "Wrong cause");
-        EasyMock.verify(init);
-    }
-
-    //-----------------------------------------------------------------------
     /**
      * Tests constant future.
      *
-     * @throws java.lang.Exception so we don't have to catch it
+     * @throws Exception so we don't have to catch it
      */
     @Test
     public void testConstantFuture_Integer() throws Exception {
@@ -374,7 +107,7 @@ public class ConcurrentUtilsTest {
     /**
      * Tests constant future.
      *
-     * @throws java.lang.Exception so we don't have to catch it
+     * @throws Exception so we don't have to catch it
      */
     @Test
     public void testConstantFuture_null() throws Exception {
@@ -389,61 +122,6 @@ public class ConcurrentUtilsTest {
         assertFalse(test.cancel(false));
     }
 
-    //-----------------------------------------------------------------------
-    /**
-     * Tests putIfAbsent() if the map contains the key in question.
-     */
-    @Test
-    public void testPutIfAbsentKeyPresent() {
-        final String key = "testKey";
-        final Integer value = 42;
-        final ConcurrentMap<String, Integer> map = new ConcurrentHashMap<>();
-        map.put(key, value);
-        assertEquals(value, ConcurrentUtils.putIfAbsent(map, key, 0), "Wrong result");
-        assertEquals(value, map.get(key), "Wrong value in map");
-    }
-
-    /**
-     * Tests putIfAbsent() if the map does not contain the key in question.
-     */
-    @Test
-    public void testPutIfAbsentKeyNotPresent() {
-        final String key = "testKey";
-        final Integer value = 42;
-        final ConcurrentMap<String, Integer> map = new ConcurrentHashMap<>();
-        assertEquals(value, ConcurrentUtils.putIfAbsent(map, key, value), "Wrong result");
-        assertEquals(value, map.get(key), "Wrong value in map");
-    }
-
-    /**
-     * Tests putIfAbsent() if a null map is passed in.
-     */
-    @Test
-    public void testPutIfAbsentNullMap() {
-        assertNull(ConcurrentUtils.putIfAbsent(null, "test", 100), "Wrong result");
-    }
-
-    /**
-     * Tests createIfAbsent() if the key is found in the map.
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
-     */
-    @Test
-    public void testCreateIfAbsentKeyPresent() throws ConcurrentException {
-        @SuppressWarnings("unchecked")
-        final
-        ConcurrentInitializer<Integer> init = EasyMock
-                .createMock(ConcurrentInitializer.class);
-        EasyMock.replay(init);
-        final String key = "testKey";
-        final Integer value = 42;
-        final ConcurrentMap<String, Integer> map = new ConcurrentHashMap<>();
-        map.put(key, value);
-        assertEquals(value, ConcurrentUtils.createIfAbsent(map, key, init), "Wrong result");
-        assertEquals(value, map.get(key), "Wrong value in map");
-        EasyMock.verify(init);
-    }
-
     /**
      * Tests createIfAbsent() if the map does not contain the key in question.
      *
@@ -451,10 +129,7 @@ public class ConcurrentUtilsTest {
      */
     @Test
     public void testCreateIfAbsentKeyNotPresent() throws ConcurrentException {
-        @SuppressWarnings("unchecked")
-        final
-        ConcurrentInitializer<Integer> init = EasyMock
-                .createMock(ConcurrentInitializer.class);
+        final ConcurrentInitializer<Integer> init = EasyMock.createMock(ConcurrentInitializer.class);
         final String key = "testKey";
         final Integer value = 42;
         EasyMock.expect(init.get()).andReturn(value);
@@ -466,18 +141,20 @@ public class ConcurrentUtilsTest {
     }
 
     /**
-     * Tests createIfAbsent() if a null map is passed in.
+     * Tests createIfAbsent() if the key is found in the map.
      *
      * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
      */
     @Test
-    public void testCreateIfAbsentNullMap() throws ConcurrentException {
-        @SuppressWarnings("unchecked")
-        final
-        ConcurrentInitializer<Integer> init = EasyMock
-                .createMock(ConcurrentInitializer.class);
+    public void testCreateIfAbsentKeyPresent() throws ConcurrentException {
+        final ConcurrentInitializer<Integer> init = EasyMock.createMock(ConcurrentInitializer.class);
         EasyMock.replay(init);
-        assertNull(ConcurrentUtils.createIfAbsent(null, "test", init), "Wrong result");
+        final String key = "testKey";
+        final Integer value = 42;
+        final ConcurrentMap<String, Integer> map = new ConcurrentHashMap<>();
+        map.put(key, value);
+        assertEquals(value, ConcurrentUtils.createIfAbsent(map, key, init), "Wrong result");
+        assertEquals(value, map.get(key), "Wrong value in map");
         EasyMock.verify(init);
     }
 
@@ -497,16 +174,16 @@ public class ConcurrentUtilsTest {
     }
 
     /**
-     * Tests createIfAbsentUnchecked() if no exception is thrown.
+     * Tests createIfAbsent() if a null map is passed in.
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
      */
     @Test
-    public void testCreateIfAbsentUncheckedSuccess() {
-        final String key = "testKey";
-        final Integer value = 42;
-        final ConcurrentMap<String, Integer> map = new ConcurrentHashMap<>();
-        assertEquals(value, ConcurrentUtils.createIfAbsentUnchecked(map, key, new ConstantInitializer<>(value)),
-                "Wrong result");
-        assertEquals(value, map.get(key), "Wrong value in map");
+    public void testCreateIfAbsentNullMap() throws ConcurrentException {
+        final ConcurrentInitializer<Integer> init = EasyMock.createMock(ConcurrentInitializer.class);
+        EasyMock.replay(init);
+        assertNull(ConcurrentUtils.createIfAbsent(null, "test", init), "Wrong result");
+        EasyMock.verify(init);
     }
 
     /**
@@ -515,20 +192,305 @@ public class ConcurrentUtilsTest {
      * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
      */
     @Test
-    public void testCreateIfAbsentUncheckedException()
-            throws ConcurrentException {
-        @SuppressWarnings("unchecked")
-        final
-        ConcurrentInitializer<Integer> init = EasyMock
-                .createMock(ConcurrentInitializer.class);
+    public void testCreateIfAbsentUncheckedException() throws ConcurrentException {
+        final ConcurrentInitializer<Integer> init = EasyMock.createMock(ConcurrentInitializer.class);
         final Exception ex = new Exception();
         EasyMock.expect(init.get()).andThrow(new ConcurrentException(ex));
         EasyMock.replay(init);
-        final ConcurrentRuntimeException crex =
-                assertThrows(
-                        ConcurrentRuntimeException.class,
-                        () -> ConcurrentUtils.createIfAbsentUnchecked(new ConcurrentHashMap<>(), "test", init));
+        final ConcurrentRuntimeException crex = assertThrows(ConcurrentRuntimeException.class,
+            () -> ConcurrentUtils.createIfAbsentUnchecked(new ConcurrentHashMap<>(), "test", init));
         assertEquals(ex, crex.getCause(), "Wrong cause");
         EasyMock.verify(init);
     }
+
+    /**
+     * Tests createIfAbsentUnchecked() if no exception is thrown.
+     */
+    @Test
+    public void testCreateIfAbsentUncheckedSuccess() {
+        final String key = "testKey";
+        final Integer value = 42;
+        final ConcurrentMap<String, Integer> map = new ConcurrentHashMap<>();
+        assertEquals(value, ConcurrentUtils.createIfAbsentUnchecked(map, key, new ConstantInitializer<>(value)), "Wrong result");
+        assertEquals(value, map.get(key), "Wrong value in map");
+    }
+
+    /**
+     * Tests extractCause() if the cause is a checked exception.
+     */
+    @Test
+    public void testExtractCauseChecked() {
+        final Exception ex = new Exception("Test");
+        final ConcurrentException cex = ConcurrentUtils.extractCause(new ExecutionException(ex));
+        assertSame(ex, cex.getCause(), "Wrong cause");
+    }
+
+    /**
+     * Tests extractCause() if the cause is an error.
+     */
+    @Test
+    public void testExtractCauseError() {
+        final Error err = new AssertionError("Test");
+        final AssertionError e = assertThrows(AssertionError.class, () -> ConcurrentUtils.extractCause(new ExecutionException(err)));
+        assertEquals(err, e, "Wrong error");
+    }
+
+    /**
+     * Tests extractCause() for a null exception.
+     */
+    @Test
+    public void testExtractCauseNull() {
+        assertNull(ConcurrentUtils.extractCause(null), "Non null result");
+    }
+
+    /**
+     * Tests extractCause() if the cause of the passed in exception is null.
+     */
+    @Test
+    public void testExtractCauseNullCause() {
+        assertNull(ConcurrentUtils.extractCause(new ExecutionException("Test", null)), "Non null result");
+    }
+
+    /**
+     * Tests extractCauseUnchecked() if the cause is a checked exception.
+     */
+    @Test
+    public void testExtractCauseUncheckedChecked() {
+        final Exception ex = new Exception("Test");
+        final ConcurrentRuntimeException cex = ConcurrentUtils.extractCauseUnchecked(new ExecutionException(ex));
+        assertSame(ex, cex.getCause(), "Wrong cause");
+    }
+
+    /**
+     * Tests extractCauseUnchecked() if the cause is an error.
+     */
+    @Test
+    public void testExtractCauseUncheckedError() {
+        final Error err = new AssertionError("Test");
+        final Error e = assertThrows(Error.class, () -> ConcurrentUtils.extractCauseUnchecked(new ExecutionException(err)));
+        assertEquals(err, e, "Wrong error");
+    }
+
+    /**
+     * Tests extractCause() if the cause is an unchecked exception.
+     */
+    @Test
+    public void testExtractCauseUncheckedException() {
+        final RuntimeException rex = new RuntimeException("Test");
+        assertThrows(RuntimeException.class, () -> ConcurrentUtils.extractCause(new ExecutionException(rex)));
+    }
+
+    /**
+     * Tests extractCauseUnchecked() for a null exception.
+     */
+    @Test
+    public void testExtractCauseUncheckedNull() {
+        assertNull(ConcurrentUtils.extractCauseUnchecked(null), "Non null result");
+    }
+
+    /**
+     * Tests extractCauseUnchecked() if the cause of the passed in exception is null.
+     */
+    @Test
+    public void testExtractCauseUncheckedNullCause() {
+        assertNull(ConcurrentUtils.extractCauseUnchecked(new ExecutionException("Test", null)), "Non null result");
+    }
+
+    /**
+     * Tests extractCauseUnchecked() if the cause is an unchecked exception.
+     */
+    @Test
+    public void testExtractCauseUncheckedUncheckedException() {
+        final RuntimeException rex = new RuntimeException("Test");
+        final RuntimeException r = assertThrows(RuntimeException.class, () -> ConcurrentUtils.extractCauseUnchecked(new ExecutionException(rex)));
+        assertEquals(rex, r, "Wrong exception");
+    }
+
+    /**
+     * Tests handleCause() if the cause is a checked exception.
+     */
+    @Test
+    public void testHandleCauseChecked() {
+        final Exception ex = new Exception("Test");
+        final ConcurrentException cex = assertThrows(ConcurrentException.class, () -> ConcurrentUtils.handleCause(new ExecutionException(ex)));
+        assertEquals(ex, cex.getCause(), "Wrong cause");
+    }
+
+    /**
+     * Tests handleCause() if the cause is an error.
+     */
+    @Test
+    public void testHandleCauseError() {
+        final Error err = new AssertionError("Test");
+        final Error e = assertThrows(Error.class, () -> ConcurrentUtils.handleCause(new ExecutionException(err)));
+        assertEquals(err, e, "Wrong error");
+    }
+
+    /**
+     * Tests handleCause() for a null parameter or a null cause. In this case the method should do nothing. We can only test
+     * that no exception is thrown.
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     */
+    @Test
+    public void testHandleCauseNull() throws ConcurrentException {
+        ConcurrentUtils.handleCause(null);
+        ConcurrentUtils.handleCause(new ExecutionException("Test", null));
+    }
+
+    /**
+     * Tests handleCauseUnchecked() if the cause is a checked exception.
+     */
+    @Test
+    public void testHandleCauseUncheckedChecked() {
+        final Exception ex = new Exception("Test");
+        final ConcurrentRuntimeException crex = assertThrows(ConcurrentRuntimeException.class,
+            () -> ConcurrentUtils.handleCauseUnchecked(new ExecutionException(ex)));
+        assertEquals(ex, crex.getCause(), "Wrong cause");
+    }
+
+    /**
+     * Tests handleCauseUnchecked() if the cause is an error.
+     */
+    @Test
+    public void testHandleCauseUncheckedError() {
+        final Error err = new AssertionError("Test");
+        final Error e = assertThrows(Error.class, () -> ConcurrentUtils.handleCauseUnchecked(new ExecutionException(err)));
+        assertEquals(err, e, "Wrong error");
+    }
+
+    /**
+     * Tests handleCause() if the cause is an unchecked exception.
+     */
+    @Test
+    public void testHandleCauseUncheckedException() {
+        final RuntimeException rex = new RuntimeException("Test");
+        final RuntimeException r = assertThrows(RuntimeException.class, () -> ConcurrentUtils.handleCause(new ExecutionException(rex)));
+        assertEquals(rex, r, "Wrong exception");
+    }
+
+    /**
+     * Tests handleCauseUnchecked() for a null parameter or a null cause. In this case the method should do nothing. We can
+     * only test that no exception is thrown.
+     */
+    @Test
+    public void testHandleCauseUncheckedNull() {
+        ConcurrentUtils.handleCauseUnchecked(null);
+        ConcurrentUtils.handleCauseUnchecked(new ExecutionException("Test", null));
+    }
+
+    /**
+     * Tests handleCauseUnchecked() if the cause is an unchecked exception.
+     */
+    @Test
+    public void testHandleCauseUncheckedUncheckedException() {
+        final RuntimeException rex = new RuntimeException("Test");
+        final RuntimeException r = assertThrows(RuntimeException.class, () -> ConcurrentUtils.handleCauseUnchecked(new ExecutionException(rex)));
+        assertEquals(rex, r, "Wrong exception");
+    }
+
+    /**
+     * Tests a successful initialize() operation.
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     */
+    @Test
+    public void testInitialize() throws ConcurrentException {
+        final ConcurrentInitializer<Object> init = EasyMock.createMock(ConcurrentInitializer.class);
+        final Object result = new Object();
+        EasyMock.expect(init.get()).andReturn(result);
+        EasyMock.replay(init);
+        assertSame(result, ConcurrentUtils.initialize(init), "Wrong result object");
+        EasyMock.verify(init);
+    }
+
+    /**
+     * Tests initialize() for a null argument.
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     */
+    @Test
+    public void testInitializeNull() throws ConcurrentException {
+        assertNull(ConcurrentUtils.initialize(null), "Got a result");
+    }
+
+    /**
+     * Tests a successful initializeUnchecked() operation.
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     */
+    @Test
+    public void testInitializeUnchecked() throws ConcurrentException {
+        final ConcurrentInitializer<Object> init = EasyMock.createMock(ConcurrentInitializer.class);
+        final Object result = new Object();
+        EasyMock.expect(init.get()).andReturn(result);
+        EasyMock.replay(init);
+        assertSame(result, ConcurrentUtils.initializeUnchecked(init), "Wrong result object");
+        EasyMock.verify(init);
+    }
+
+    /**
+     * Tests whether exceptions are correctly handled by initializeUnchecked().
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     */
+    @Test
+    public void testInitializeUncheckedEx() throws ConcurrentException {
+        final ConcurrentInitializer<Object> init = EasyMock.createMock(ConcurrentInitializer.class);
+        final Exception cause = new Exception();
+        EasyMock.expect(init.get()).andThrow(new ConcurrentException(cause));
+        EasyMock.replay(init);
+        final ConcurrentRuntimeException crex = assertThrows(ConcurrentRuntimeException.class, () -> ConcurrentUtils.initializeUnchecked(init));
+        assertSame(cause, crex.getCause(), "Wrong cause");
+        EasyMock.verify(init);
+    }
+
+    /**
+     * Tests initializeUnchecked() for a null argument.
+     */
+    @Test
+    public void testInitializeUncheckedNull() {
+        assertNull(ConcurrentUtils.initializeUnchecked(null), "Got a result");
+    }
+
+    /**
+     * Tests putIfAbsent() if the map does not contain the key in question.
+     */
+    @Test
+    public void testPutIfAbsentKeyNotPresent() {
+        final String key = "testKey";
+        final Integer value = 42;
+        final ConcurrentMap<String, Integer> map = new ConcurrentHashMap<>();
+        assertEquals(value, ConcurrentUtils.putIfAbsent(map, key, value), "Wrong result");
+        assertEquals(value, map.get(key), "Wrong value in map");
+    }
+
+    /**
+     * Tests putIfAbsent() if the map contains the key in question.
+     */
+    @Test
+    public void testPutIfAbsentKeyPresent() {
+        final String key = "testKey";
+        final Integer value = 42;
+        final ConcurrentMap<String, Integer> map = new ConcurrentHashMap<>();
+        map.put(key, value);
+        assertEquals(value, ConcurrentUtils.putIfAbsent(map, key, 0), "Wrong result");
+        assertEquals(value, map.get(key), "Wrong value in map");
+    }
+
+    /**
+     * Tests putIfAbsent() if a null map is passed in.
+     */
+    @Test
+    public void testPutIfAbsentNullMap() {
+        assertNull(ConcurrentUtils.putIfAbsent(null, "test", 100), "Wrong result");
+    }
+
+    /**
+     * Tests creating ConcurrentRuntimeException with no arguments.
+     */
+    @Test
+    public void testUninitializedConcurrentRuntimeException() {
+        assertNotNull(new ConcurrentRuntimeException(), "Error creating empty ConcurrentRuntimeException");
+    }
 }
