@@ -20,6 +20,7 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.junit.jupiter.api.Test;
 
 /**
@@ -27,7 +28,7 @@ import org.junit.jupiter.api.Test;
  *
  * @see MutableInt
  */
-public class MutableIntTest {
+public class MutableIntTest extends AbstractLangTest {
 
     @Test
     public void testAddAndGetValueObject() {
@@ -85,7 +86,6 @@ public class MutableIntTest {
         assertThrows(NullPointerException.class, () -> new MutableInt((Number) null));
     }
 
-    // ----------------------------------------------------------------
     @Test
     public void testConstructors() {
         assertEquals(0, new MutableInt().intValue());
