@@ -30,29 +30,39 @@ public class TypeLiteralTest extends AbstractLangTest {
 
     @Test
     public void testBasic() {
-        assertTrue(TypeUtils.equals(String.class, new TypeLiteral<String>() {}.value));
-        assertTrue(TypeUtils.equals(TypeUtils.parameterize(List.class, String.class),
-            new TypeLiteral<List<String>>() {}.value));
+        assertTrue(TypeUtils.equals(String.class, new TypeLiteral<String>() {
+        }.value));
+        assertTrue(TypeUtils.equals(TypeUtils.parameterize(List.class, String.class), new TypeLiteral<List<String>>() {
+        }.value));
     }
 
     @Test
     public void testEquals() {
-        assertEquals(new TypeLiteral<String>() {}, new TypeLiteral<String>() {});
-        assertEquals(new TypeLiteral<List<String>>() {}, new TypeLiteral<List<String>>() {});
-        assertNotEquals(new TypeLiteral<String>() {}, new TypeLiteral<List<String>>() {});
+        assertEquals(new TypeLiteral<String>() {
+        }, new TypeLiteral<String>() {
+        });
+        assertEquals(new TypeLiteral<List<String>>() {
+        }, new TypeLiteral<List<String>>() {
+        });
+        assertNotEquals(new TypeLiteral<String>() {
+        }, new TypeLiteral<List<String>>() {
+        });
     }
 
     @SuppressWarnings("rawtypes")
     @Test
     public void testRaw() {
-        assertThrows(NullPointerException.class, () -> new TypeLiteral() {});
+        assertThrows(NullPointerException.class, () -> new TypeLiteral() {
+        });
     }
 
     @Test
     public void testTyped() {
-        final Typed<String> stringType = new TypeLiteral<String>() {};
+        final Typed<String> stringType = new TypeLiteral<String>() {
+        };
         assertTrue(TypeUtils.equals(String.class, stringType.getType()));
-        final Typed<List<String>> listOfStringType = new TypeLiteral<List<String>>() {};
+        final Typed<List<String>> listOfStringType = new TypeLiteral<List<String>>() {
+        };
         assertTrue(TypeUtils.equals(TypeUtils.parameterize(List.class, String.class), listOfStringType.getType()));
     }
 }
