@@ -21,9 +21,24 @@ import java.util.List;
 /**
  * Holds generic testbed types.
  */
+@SuppressWarnings("rawtypes")
 public class GenericTypeHolder {
     public GenericParent<String> stringParent;
     public GenericParent<Integer> integerParent;
     public List<Foo> foos;
     public GenericParent<Bar>[] barParents;
+    public List rawList;
+    public List<Object> objectList;
+    public List<?> unboundList;
+    public List<? super Object> superObjectList;
+    public List<String> stringList;
+    public List<? extends String> subStringList;
+    public List<? super String> superStringList;
+    public List[] rawListArray;
+    public List<Object>[] objectListArray;
+    public List<?>[] unboundListArray;
+    public List<? super Object>[] superObjectListArray;
+    public List<String>[] stringListArray;
+    public List<? extends String>[] subStringListArray;
+    public List<? super String>[] superStringListArray;
 }
