@@ -25,15 +25,79 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.junit.jupiter.api.Test;
 
 /**
  * Unit tests for WordUtils class.
  */
 @Deprecated
-public class WordUtilsTest {
+public class WordUtilsTest extends AbstractLangTest {
+
+    @Test
+    public void testCapitalize_String() {
+        assertNull(WordUtils.capitalize(null));
+        assertEquals("", WordUtils.capitalize(""));
+        assertEquals("  ", WordUtils.capitalize("  "));
+
+        assertEquals("I", WordUtils.capitalize("I") );
+        assertEquals("I", WordUtils.capitalize("i") );
+        assertEquals("I Am Here 123", WordUtils.capitalize("i am here 123") );
+        assertEquals("I Am Here 123", WordUtils.capitalize("I Am Here 123") );
+        assertEquals("I Am HERE 123", WordUtils.capitalize("i am HERE 123") );
+        assertEquals("I AM HERE 123", WordUtils.capitalize("I AM HERE 123") );
+    }
+
+    @Test
+    public void testCapitalizeFully_String() {
+        assertNull(WordUtils.capitalizeFully(null));
+        assertEquals("", WordUtils.capitalizeFully(""));
+        assertEquals("  ", WordUtils.capitalizeFully("  "));
+
+        assertEquals("I", WordUtils.capitalizeFully("I") );
+        assertEquals("I", WordUtils.capitalizeFully("i") );
+        assertEquals("I Am Here 123", WordUtils.capitalizeFully("i am here 123") );
+        assertEquals("I Am Here 123", WordUtils.capitalizeFully("I Am Here 123") );
+        assertEquals("I Am Here 123", WordUtils.capitalizeFully("i am HERE 123") );
+        assertEquals("I Am Here 123", WordUtils.capitalizeFully("I AM HERE 123") );
+    }
+
+    @Test
+    public void testCapitalizeFullyWithDelimiters_String() {
+        assertNull(WordUtils.capitalizeFully(null, null));
+        assertEquals("", WordUtils.capitalizeFully(""));
+        assertEquals("  ", WordUtils.capitalizeFully("  "));
+
+        char[] chars = { '-', '+', ' ', '@' };
+        assertEquals("I", WordUtils.capitalizeFully("I", chars) );
+        assertEquals("I", WordUtils.capitalizeFully("i", chars) );
+        assertEquals("I-Am Here+123", WordUtils.capitalizeFully("i-am here+123", chars) );
+        assertEquals("I Am+Here-123", WordUtils.capitalizeFully("I Am+Here-123", chars) );
+        assertEquals("I+Am-Here 123", WordUtils.capitalizeFully("i+am-HERE 123", chars) );
+        assertEquals("I-Am Here+123", WordUtils.capitalizeFully("I-AM HERE+123", chars) );
+        chars = new char[] {'.'};
+        assertEquals("I am.Fine", WordUtils.capitalizeFully("i aM.fine", chars) );
+        assertEquals("I Am.fine", WordUtils.capitalizeFully("i am.fine", null) );
+    }
+
+    @Test
+    public void testCapitalizeWithDelimiters_String() {
+        assertNull(WordUtils.capitalize(null, null));
+        assertEquals("", WordUtils.capitalize(""));
+        assertEquals("  ", WordUtils.capitalize("  "));
+
+        char[] chars = { '-', '+', ' ', '@' };
+        assertEquals("I", WordUtils.capitalize("I", chars) );
+        assertEquals("I", WordUtils.capitalize("i", chars) );
+        assertEquals("I-Am Here+123", WordUtils.capitalize("i-am here+123", chars) );
+        assertEquals("I Am+Here-123", WordUtils.capitalize("I Am+Here-123", chars) );
+        assertEquals("I+Am-HERE 123", WordUtils.capitalize("i+am-HERE 123", chars) );
+        assertEquals("I-AM HERE+123", WordUtils.capitalize("I-AM HERE+123", chars) );
+        chars = new char[] {'.'};
+        assertEquals("I aM.Fine", WordUtils.capitalize("i aM.fine", chars) );
+        assertEquals("I Am.fine", WordUtils.capitalize("i am.fine", null) );
+    }
 
-    //-----------------------------------------------------------------------
     @Test
     public void testConstructor() {
         assertNotNull(new WordUtils());
@@ -44,7 +108,191 @@ public class WordUtilsTest {
         assertFalse(Modifier.isFinal(WordUtils.class.getModifiers()));
     }
 
-    //-----------------------------------------------------------------------
+    @Test
+    public void testContainsAllWords_StringString() {
+        assertFalse(WordUtils.containsAllWords(null, (String) null));
+        assertFalse(WordUtils.containsAllWords(null, ""));
+        assertFalse(WordUtils.containsAllWords(null, "ab"));
+
+        assertFalse(WordUtils.containsAllWords("", (String) null));
+        assertFalse(WordUtils.containsAllWords("", ""));
+        assertFalse(WordUtils.containsAllWords("", "ab"));
+
+        assertFalse(WordUtils.containsAllWords("foo", (String) null));
+        assertFalse(WordUtils.containsAllWords("bar", ""));
+        assertFalse(WordUtils.containsAllWords("zzabyycdxx", "by"));
+        assertTrue(WordUtils.containsAllWords("lorem ipsum dolor sit amet", "ipsum", "lorem", "dolor"));
+        assertFalse(WordUtils.containsAllWords("lorem ipsum dolor sit amet", "ipsum", null, "lorem", "dolor"));
+        assertFalse(WordUtils.containsAllWords("lorem ipsum null dolor sit amet", "ipsum", null, "lorem", "dolor"));
+        assertFalse(WordUtils.containsAllWords("ab", "b"));
+        assertFalse(WordUtils.containsAllWords("ab", "z"));
+    }
+
+    @Test
+    public void testInitials_String() {
+        assertNull(WordUtils.initials(null));
+        assertEquals("", WordUtils.initials(""));
+        assertEquals("", WordUtils.initials("  "));
+
+        assertEquals("I", WordUtils.initials("I"));
+        assertEquals("i", WordUtils.initials("i"));
+        assertEquals("BJL", WordUtils.initials("Ben John Lee"));
+        assertEquals("BJL", WordUtils.initials("   Ben \n   John\tLee\t"));
+        assertEquals("BJ", WordUtils.initials("Ben J.Lee"));
+        assertEquals("BJ.L", WordUtils.initials(" Ben   John  . Lee"));
+        assertEquals("iah1", WordUtils.initials("i am here 123"));
+    }
+
+    @Test
+    public void testInitials_String_charArray() {
+        char[] array = null;
+        assertNull(WordUtils.initials(null, array));
+        assertEquals("", WordUtils.initials("", array));
+        assertEquals("", WordUtils.initials("  ", array));
+        assertEquals("I", WordUtils.initials("I", array));
+        assertEquals("i", WordUtils.initials("i", array));
+        assertEquals("S", WordUtils.initials("SJC", array));
+        assertEquals("BJL", WordUtils.initials("Ben John Lee", array));
+        assertEquals("BJL", WordUtils.initials("   Ben \n   John\tLee\t", array));
+        assertEquals("BJ", WordUtils.initials("Ben J.Lee", array));
+        assertEquals("BJ.L", WordUtils.initials(" Ben   John  . Lee", array));
+        assertEquals("KO", WordUtils.initials("Kay O'Murphy", array));
+        assertEquals("iah1", WordUtils.initials("i am here 123", array));
+
+        array = new char[0];
+        assertNull(WordUtils.initials(null, array));
+        assertEquals("", WordUtils.initials("", array));
+        assertEquals("", WordUtils.initials("  ", array));
+        assertEquals("", WordUtils.initials("I", array));
+        assertEquals("", WordUtils.initials("i", array));
+        assertEquals("", WordUtils.initials("SJC", array));
+        assertEquals("", WordUtils.initials("Ben John Lee", array));
+        assertEquals("", WordUtils.initials("   Ben \n   John\tLee\t", array));
+        assertEquals("", WordUtils.initials("Ben J.Lee", array));
+        assertEquals("", WordUtils.initials(" Ben   John  . Lee", array));
+        assertEquals("", WordUtils.initials("Kay O'Murphy", array));
+        assertEquals("", WordUtils.initials("i am here 123", array));
+
+        array = " ".toCharArray();
+        assertNull(WordUtils.initials(null, array));
+        assertEquals("", WordUtils.initials("", array));
+        assertEquals("", WordUtils.initials("  ", array));
+        assertEquals("I", WordUtils.initials("I", array));
+        assertEquals("i", WordUtils.initials("i", array));
+        assertEquals("S", WordUtils.initials("SJC", array));
+        assertEquals("BJL", WordUtils.initials("Ben John Lee", array));
+        assertEquals("BJ", WordUtils.initials("Ben J.Lee", array));
+        assertEquals("B\nJ", WordUtils.initials("   Ben \n   John\tLee\t", array));
+        assertEquals("BJ.L", WordUtils.initials(" Ben   John  . Lee", array));
+        assertEquals("KO", WordUtils.initials("Kay O'Murphy", array));
+        assertEquals("iah1", WordUtils.initials("i am here 123", array));
+
+        array = " .".toCharArray();
+        assertNull(WordUtils.initials(null, array));
+        assertEquals("", WordUtils.initials("", array));
+        assertEquals("", WordUtils.initials("  ", array));
+        assertEquals("I", WordUtils.initials("I", array));
+        assertEquals("i", WordUtils.initials("i", array));
+        assertEquals("S", WordUtils.initials("SJC", array));
+        assertEquals("BJL", WordUtils.initials("Ben John Lee", array));
+        assertEquals("BJL", WordUtils.initials("Ben J.Lee", array));
+        assertEquals("BJL", WordUtils.initials(" Ben   John  . Lee", array));
+        assertEquals("KO", WordUtils.initials("Kay O'Murphy", array));
+        assertEquals("iah1", WordUtils.initials("i am here 123", array));
+
+        array = " .'".toCharArray();
+        assertNull(WordUtils.initials(null, array));
+        assertEquals("", WordUtils.initials("", array));
+        assertEquals("", WordUtils.initials("  ", array));
+        assertEquals("I", WordUtils.initials("I", array));
+        assertEquals("i", WordUtils.initials("i", array));
+        assertEquals("S", WordUtils.initials("SJC", array));
+        assertEquals("BJL", WordUtils.initials("Ben John Lee", array));
+        assertEquals("BJL", WordUtils.initials("Ben J.Lee", array));
+        assertEquals("BJL", WordUtils.initials(" Ben   John  . Lee", array));
+        assertEquals("KOM", WordUtils.initials("Kay O'Murphy", array));
+        assertEquals("iah1", WordUtils.initials("i am here 123", array));
+
+        array = "SIJo1".toCharArray();
+        assertNull(WordUtils.initials(null, array));
+        assertEquals("", WordUtils.initials("", array));
+        assertEquals(" ", WordUtils.initials("  ", array));
+        assertEquals("", WordUtils.initials("I", array));
+        assertEquals("i", WordUtils.initials("i", array));
+        assertEquals("C", WordUtils.initials("SJC", array));
+        assertEquals("Bh", WordUtils.initials("Ben John Lee", array));
+        assertEquals("B.", WordUtils.initials("Ben J.Lee", array));
+        assertEquals(" h", WordUtils.initials(" Ben   John  . Lee", array));
+        assertEquals("K", WordUtils.initials("Kay O'Murphy", array));
+        assertEquals("i2", WordUtils.initials("i am here 123", array));
+    }
+
+    @Test
+    public void testLANG1292() {
+        // Prior to fix, this was throwing StringIndexOutOfBoundsException
+        WordUtils.wrap("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa "
+                + "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa "
+                + "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", 70);
+    }
+
+    @Test
+    public void testLANG1397() {
+        // Prior to fix, this was throwing StringIndexOutOfBoundsException
+        WordUtils.wrap("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa "
+            + "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa "
+            + "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", Integer.MAX_VALUE);
+    }
+
+    @Test
+    public void testSwapCase_String() {
+        assertNull(WordUtils.swapCase(null));
+        assertEquals("", WordUtils.swapCase(""));
+        assertEquals("  ", WordUtils.swapCase("  "));
+
+        assertEquals("i", WordUtils.swapCase("I") );
+        assertEquals("I", WordUtils.swapCase("i") );
+        assertEquals("I AM HERE 123", WordUtils.swapCase("i am here 123") );
+        assertEquals("i aM hERE 123", WordUtils.swapCase("I Am Here 123") );
+        assertEquals("I AM here 123", WordUtils.swapCase("i am HERE 123") );
+        assertEquals("i am here 123", WordUtils.swapCase("I AM HERE 123") );
+
+        final String test = "This String contains a TitleCase character: \u01C8";
+        final String expect = "tHIS sTRING CONTAINS A tITLEcASE CHARACTER: \u01C9";
+        assertEquals(expect, WordUtils.swapCase(test));
+    }
+
+    @Test
+    public void testUncapitalize_String() {
+        assertNull(WordUtils.uncapitalize(null));
+        assertEquals("", WordUtils.uncapitalize(""));
+        assertEquals("  ", WordUtils.uncapitalize("  "));
+
+        assertEquals("i", WordUtils.uncapitalize("I") );
+        assertEquals("i", WordUtils.uncapitalize("i") );
+        assertEquals("i am here 123", WordUtils.uncapitalize("i am here 123") );
+        assertEquals("i am here 123", WordUtils.uncapitalize("I Am Here 123") );
+        assertEquals("i am hERE 123", WordUtils.uncapitalize("i am HERE 123") );
+        assertEquals("i aM hERE 123", WordUtils.uncapitalize("I AM HERE 123") );
+    }
+
+    @Test
+    public void testUncapitalizeWithDelimiters_String() {
+        assertNull(WordUtils.uncapitalize(null, null));
+        assertEquals("", WordUtils.uncapitalize(""));
+        assertEquals("  ", WordUtils.uncapitalize("  "));
+
+        char[] chars = { '-', '+', ' ', '@' };
+        assertEquals("i", WordUtils.uncapitalize("I", chars) );
+        assertEquals("i", WordUtils.uncapitalize("i", chars) );
+        assertEquals("i am-here+123", WordUtils.uncapitalize("i am-here+123", chars) );
+        assertEquals("i+am here-123", WordUtils.uncapitalize("I+Am Here-123", chars) );
+        assertEquals("i-am+hERE 123", WordUtils.uncapitalize("i-am+HERE 123", chars) );
+        assertEquals("i aM-hERE+123", WordUtils.uncapitalize("I AM-HERE+123", chars) );
+        chars = new char[] {'.'};
+        assertEquals("i AM.fINE", WordUtils.uncapitalize("I AM.FINE", chars) );
+        assertEquals("i aM.FINE", WordUtils.uncapitalize("I AM.FINE", null) );
+    }
+
     @Test
     public void testWrap_StringInt() {
         assertNull(WordUtils.wrap(null, 20));
@@ -181,257 +429,4 @@ public class WordUtilsTest {
         expected = "flammableinflam\nmable";
         assertEquals(expected, WordUtils.wrap(input, 15, "\n", true, "/"));
     }
-
-    //-----------------------------------------------------------------------
-    @Test
-    public void testCapitalize_String() {
-        assertNull(WordUtils.capitalize(null));
-        assertEquals("", WordUtils.capitalize(""));
-        assertEquals("  ", WordUtils.capitalize("  "));
-
-        assertEquals("I", WordUtils.capitalize("I") );
-        assertEquals("I", WordUtils.capitalize("i") );
-        assertEquals("I Am Here 123", WordUtils.capitalize("i am here 123") );
-        assertEquals("I Am Here 123", WordUtils.capitalize("I Am Here 123") );
-        assertEquals("I Am HERE 123", WordUtils.capitalize("i am HERE 123") );
-        assertEquals("I AM HERE 123", WordUtils.capitalize("I AM HERE 123") );
-    }
-
-    @Test
-    public void testCapitalizeWithDelimiters_String() {
-        assertNull(WordUtils.capitalize(null, null));
-        assertEquals("", WordUtils.capitalize(""));
-        assertEquals("  ", WordUtils.capitalize("  "));
-
-        char[] chars = new char[] { '-', '+', ' ', '@' };
-        assertEquals("I", WordUtils.capitalize("I", chars) );
-        assertEquals("I", WordUtils.capitalize("i", chars) );
-        assertEquals("I-Am Here+123", WordUtils.capitalize("i-am here+123", chars) );
-        assertEquals("I Am+Here-123", WordUtils.capitalize("I Am+Here-123", chars) );
-        assertEquals("I+Am-HERE 123", WordUtils.capitalize("i+am-HERE 123", chars) );
-        assertEquals("I-AM HERE+123", WordUtils.capitalize("I-AM HERE+123", chars) );
-        chars = new char[] {'.'};
-        assertEquals("I aM.Fine", WordUtils.capitalize("i aM.fine", chars) );
-        assertEquals("I Am.fine", WordUtils.capitalize("i am.fine", null) );
-    }
-
-    @Test
-    public void testCapitalizeFully_String() {
-        assertNull(WordUtils.capitalizeFully(null));
-        assertEquals("", WordUtils.capitalizeFully(""));
-        assertEquals("  ", WordUtils.capitalizeFully("  "));
-
-        assertEquals("I", WordUtils.capitalizeFully("I") );
-        assertEquals("I", WordUtils.capitalizeFully("i") );
-        assertEquals("I Am Here 123", WordUtils.capitalizeFully("i am here 123") );
-        assertEquals("I Am Here 123", WordUtils.capitalizeFully("I Am Here 123") );
-        assertEquals("I Am Here 123", WordUtils.capitalizeFully("i am HERE 123") );
-        assertEquals("I Am Here 123", WordUtils.capitalizeFully("I AM HERE 123") );
-    }
-
-    @Test
-    public void testCapitalizeFullyWithDelimiters_String() {
-        assertNull(WordUtils.capitalizeFully(null, null));
-        assertEquals("", WordUtils.capitalizeFully(""));
-        assertEquals("  ", WordUtils.capitalizeFully("  "));
-
-        char[] chars = new char[] { '-', '+', ' ', '@' };
-        assertEquals("I", WordUtils.capitalizeFully("I", chars) );
-        assertEquals("I", WordUtils.capitalizeFully("i", chars) );
-        assertEquals("I-Am Here+123", WordUtils.capitalizeFully("i-am here+123", chars) );
-        assertEquals("I Am+Here-123", WordUtils.capitalizeFully("I Am+Here-123", chars) );
-        assertEquals("I+Am-Here 123", WordUtils.capitalizeFully("i+am-HERE 123", chars) );
-        assertEquals("I-Am Here+123", WordUtils.capitalizeFully("I-AM HERE+123", chars) );
-        chars = new char[] {'.'};
-        assertEquals("I am.Fine", WordUtils.capitalizeFully("i aM.fine", chars) );
-        assertEquals("I Am.fine", WordUtils.capitalizeFully("i am.fine", null) );
-    }
-
-    @Test
-    public void testContainsAllWords_StringString() {
-        assertFalse(WordUtils.containsAllWords(null, (String) null));
-        assertFalse(WordUtils.containsAllWords(null, ""));
-        assertFalse(WordUtils.containsAllWords(null, "ab"));
-
-        assertFalse(WordUtils.containsAllWords("", (String) null));
-        assertFalse(WordUtils.containsAllWords("", ""));
-        assertFalse(WordUtils.containsAllWords("", "ab"));
-
-        assertFalse(WordUtils.containsAllWords("foo", (String) null));
-        assertFalse(WordUtils.containsAllWords("bar", ""));
-        assertFalse(WordUtils.containsAllWords("zzabyycdxx", "by"));
-        assertTrue(WordUtils.containsAllWords("lorem ipsum dolor sit amet", "ipsum", "lorem", "dolor"));
-        assertFalse(WordUtils.containsAllWords("lorem ipsum dolor sit amet", "ipsum", null, "lorem", "dolor"));
-        assertFalse(WordUtils.containsAllWords("lorem ipsum null dolor sit amet", "ipsum", null, "lorem", "dolor"));
-        assertFalse(WordUtils.containsAllWords("ab", "b"));
-        assertFalse(WordUtils.containsAllWords("ab", "z"));
-    }
-
-    @Test
-    public void testUncapitalize_String() {
-        assertNull(WordUtils.uncapitalize(null));
-        assertEquals("", WordUtils.uncapitalize(""));
-        assertEquals("  ", WordUtils.uncapitalize("  "));
-
-        assertEquals("i", WordUtils.uncapitalize("I") );
-        assertEquals("i", WordUtils.uncapitalize("i") );
-        assertEquals("i am here 123", WordUtils.uncapitalize("i am here 123") );
-        assertEquals("i am here 123", WordUtils.uncapitalize("I Am Here 123") );
-        assertEquals("i am hERE 123", WordUtils.uncapitalize("i am HERE 123") );
-        assertEquals("i aM hERE 123", WordUtils.uncapitalize("I AM HERE 123") );
-    }
-
-    @Test
-    public void testUncapitalizeWithDelimiters_String() {
-        assertNull(WordUtils.uncapitalize(null, null));
-        assertEquals("", WordUtils.uncapitalize(""));
-        assertEquals("  ", WordUtils.uncapitalize("  "));
-
-        char[] chars = new char[] { '-', '+', ' ', '@' };
-        assertEquals("i", WordUtils.uncapitalize("I", chars) );
-        assertEquals("i", WordUtils.uncapitalize("i", chars) );
-        assertEquals("i am-here+123", WordUtils.uncapitalize("i am-here+123", chars) );
-        assertEquals("i+am here-123", WordUtils.uncapitalize("I+Am Here-123", chars) );
-        assertEquals("i-am+hERE 123", WordUtils.uncapitalize("i-am+HERE 123", chars) );
-        assertEquals("i aM-hERE+123", WordUtils.uncapitalize("I AM-HERE+123", chars) );
-        chars = new char[] {'.'};
-        assertEquals("i AM.fINE", WordUtils.uncapitalize("I AM.FINE", chars) );
-        assertEquals("i aM.FINE", WordUtils.uncapitalize("I AM.FINE", null) );
-    }
-
-    //-----------------------------------------------------------------------
-    @Test
-    public void testInitials_String() {
-        assertNull(WordUtils.initials(null));
-        assertEquals("", WordUtils.initials(""));
-        assertEquals("", WordUtils.initials("  "));
-
-        assertEquals("I", WordUtils.initials("I"));
-        assertEquals("i", WordUtils.initials("i"));
-        assertEquals("BJL", WordUtils.initials("Ben John Lee"));
-        assertEquals("BJL", WordUtils.initials("   Ben \n   John\tLee\t"));
-        assertEquals("BJ", WordUtils.initials("Ben J.Lee"));
-        assertEquals("BJ.L", WordUtils.initials(" Ben   John  . Lee"));
-        assertEquals("iah1", WordUtils.initials("i am here 123"));
-    }
-
-    // -----------------------------------------------------------------------
-    @Test
-    public void testInitials_String_charArray() {
-        char[] array = null;
-        assertNull(WordUtils.initials(null, array));
-        assertEquals("", WordUtils.initials("", array));
-        assertEquals("", WordUtils.initials("  ", array));
-        assertEquals("I", WordUtils.initials("I", array));
-        assertEquals("i", WordUtils.initials("i", array));
-        assertEquals("S", WordUtils.initials("SJC", array));
-        assertEquals("BJL", WordUtils.initials("Ben John Lee", array));
-        assertEquals("BJL", WordUtils.initials("   Ben \n   John\tLee\t", array));
-        assertEquals("BJ", WordUtils.initials("Ben J.Lee", array));
-        assertEquals("BJ.L", WordUtils.initials(" Ben   John  . Lee", array));
-        assertEquals("KO", WordUtils.initials("Kay O'Murphy", array));
-        assertEquals("iah1", WordUtils.initials("i am here 123", array));
-
-        array = new char[0];
-        assertNull(WordUtils.initials(null, array));
-        assertEquals("", WordUtils.initials("", array));
-        assertEquals("", WordUtils.initials("  ", array));
-        assertEquals("", WordUtils.initials("I", array));
-        assertEquals("", WordUtils.initials("i", array));
-        assertEquals("", WordUtils.initials("SJC", array));
-        assertEquals("", WordUtils.initials("Ben John Lee", array));
-        assertEquals("", WordUtils.initials("   Ben \n   John\tLee\t", array));
-        assertEquals("", WordUtils.initials("Ben J.Lee", array));
-        assertEquals("", WordUtils.initials(" Ben   John  . Lee", array));
-        assertEquals("", WordUtils.initials("Kay O'Murphy", array));
-        assertEquals("", WordUtils.initials("i am here 123", array));
-
-        array = " ".toCharArray();
-        assertNull(WordUtils.initials(null, array));
-        assertEquals("", WordUtils.initials("", array));
-        assertEquals("", WordUtils.initials("  ", array));
-        assertEquals("I", WordUtils.initials("I", array));
-        assertEquals("i", WordUtils.initials("i", array));
-        assertEquals("S", WordUtils.initials("SJC", array));
-        assertEquals("BJL", WordUtils.initials("Ben John Lee", array));
-        assertEquals("BJ", WordUtils.initials("Ben J.Lee", array));
-        assertEquals("B\nJ", WordUtils.initials("   Ben \n   John\tLee\t", array));
-        assertEquals("BJ.L", WordUtils.initials(" Ben   John  . Lee", array));
-        assertEquals("KO", WordUtils.initials("Kay O'Murphy", array));
-        assertEquals("iah1", WordUtils.initials("i am here 123", array));
-
-        array = " .".toCharArray();
-        assertNull(WordUtils.initials(null, array));
-        assertEquals("", WordUtils.initials("", array));
-        assertEquals("", WordUtils.initials("  ", array));
-        assertEquals("I", WordUtils.initials("I", array));
-        assertEquals("i", WordUtils.initials("i", array));
-        assertEquals("S", WordUtils.initials("SJC", array));
-        assertEquals("BJL", WordUtils.initials("Ben John Lee", array));
-        assertEquals("BJL", WordUtils.initials("Ben J.Lee", array));
-        assertEquals("BJL", WordUtils.initials(" Ben   John  . Lee", array));
-        assertEquals("KO", WordUtils.initials("Kay O'Murphy", array));
-        assertEquals("iah1", WordUtils.initials("i am here 123", array));
-
-        array = " .'".toCharArray();
-        assertNull(WordUtils.initials(null, array));
-        assertEquals("", WordUtils.initials("", array));
-        assertEquals("", WordUtils.initials("  ", array));
-        assertEquals("I", WordUtils.initials("I", array));
-        assertEquals("i", WordUtils.initials("i", array));
-        assertEquals("S", WordUtils.initials("SJC", array));
-        assertEquals("BJL", WordUtils.initials("Ben John Lee", array));
-        assertEquals("BJL", WordUtils.initials("Ben J.Lee", array));
-        assertEquals("BJL", WordUtils.initials(" Ben   John  . Lee", array));
-        assertEquals("KOM", WordUtils.initials("Kay O'Murphy", array));
-        assertEquals("iah1", WordUtils.initials("i am here 123", array));
-
-        array = "SIJo1".toCharArray();
-        assertNull(WordUtils.initials(null, array));
-        assertEquals("", WordUtils.initials("", array));
-        assertEquals(" ", WordUtils.initials("  ", array));
-        assertEquals("", WordUtils.initials("I", array));
-        assertEquals("i", WordUtils.initials("i", array));
-        assertEquals("C", WordUtils.initials("SJC", array));
-        assertEquals("Bh", WordUtils.initials("Ben John Lee", array));
-        assertEquals("B.", WordUtils.initials("Ben J.Lee", array));
-        assertEquals(" h", WordUtils.initials(" Ben   John  . Lee", array));
-        assertEquals("K", WordUtils.initials("Kay O'Murphy", array));
-        assertEquals("i2", WordUtils.initials("i am here 123", array));
-    }
-
-    // -----------------------------------------------------------------------
-    @Test
-    public void testSwapCase_String() {
-        assertNull(WordUtils.swapCase(null));
-        assertEquals("", WordUtils.swapCase(""));
-        assertEquals("  ", WordUtils.swapCase("  "));
-
-        assertEquals("i", WordUtils.swapCase("I") );
-        assertEquals("I", WordUtils.swapCase("i") );
-        assertEquals("I AM HERE 123", WordUtils.swapCase("i am here 123") );
-        assertEquals("i aM hERE 123", WordUtils.swapCase("I Am Here 123") );
-        assertEquals("I AM here 123", WordUtils.swapCase("i am HERE 123") );
-        assertEquals("i am here 123", WordUtils.swapCase("I AM HERE 123") );
-
-        final String test = "This String contains a TitleCase character: \u01C8";
-        final String expect = "tHIS sTRING CONTAINS A tITLEcASE CHARACTER: \u01C9";
-        assertEquals(expect, WordUtils.swapCase(test));
-    }
-
-    @Test
-    public void testLANG1292() {
-        // Prior to fix, this was throwing StringIndexOutOfBoundsException
-        WordUtils.wrap("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa "
-                + "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa "
-                + "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", 70);
-    }
-
-    @Test
-    public void testLANG1397() {
-        // Prior to fix, this was throwing StringIndexOutOfBoundsException
-        WordUtils.wrap("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa "
-            + "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa "
-            + "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", Integer.MAX_VALUE);
-    }
 }
