@@ -22,14 +22,15 @@ import static org.junit.jupiter.api.Assertions.assertThrows;
 import java.util.Calendar;
 import java.util.Date;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
-public class DateUtilsFragmentTest {
+public class DateUtilsFragmentTest extends AbstractLangTest {
 
-    private static final int months = 7;   // second final prime before 12
-    private static final int days = 23;    // second final prime before 31 (and valid)
-    private static final int hours = 19;   // second final prime before 24
+    private static final int months = 7; // second final prime before 12
+    private static final int days = 23; // second final prime before 31 (and valid)
+    private static final int hours = 19; // second final prime before 24
     private static final int minutes = 53; // second final prime before 60
     private static final int seconds = 47; // third final prime before 60
     private static final int millis = 991; // second final prime before 1000
@@ -37,7 +38,6 @@ public class DateUtilsFragmentTest {
     private Date aDate;
     private Calendar aCalendar;
 
-
     @BeforeEach
     public void setUp() {
         aCalendar = Calendar.getInstance();
@@ -127,25 +127,19 @@ public class DateUtilsFragmentTest {
     @Test
     public void testHoursOfMonthWithCalendar() {
         final long testResult = DateUtils.getFragmentInHours(aCalendar, Calendar.MONTH);
-        assertEquals( hours +(((days - 1) * DateUtils.MILLIS_PER_DAY))
-                        / DateUtils.MILLIS_PER_HOUR,
-                testResult);
+        assertEquals(hours + (days - 1) * DateUtils.MILLIS_PER_DAY / DateUtils.MILLIS_PER_HOUR, testResult);
     }
 
     @Test
     public void testHoursOfMonthWithDate() {
         final long testResult = DateUtils.getFragmentInHours(aDate, Calendar.MONTH);
-        assertEquals(hours + (((days - 1) * DateUtils.MILLIS_PER_DAY))
-                        / DateUtils.MILLIS_PER_HOUR,
-                testResult);
+        assertEquals(hours + (days - 1) * DateUtils.MILLIS_PER_DAY / DateUtils.MILLIS_PER_HOUR, testResult);
     }
 
     @Test
     public void testHoursOfYearWithCalendar() {
         final long testResult = DateUtils.getFragmentInHours(aCalendar, Calendar.YEAR);
-        assertEquals( hours +(((aCalendar.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY))
-                        / DateUtils.MILLIS_PER_HOUR,
-                testResult);
+        assertEquals(hours + (aCalendar.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY / DateUtils.MILLIS_PER_HOUR, testResult);
     }
 
     @Test
@@ -153,12 +147,10 @@ public class DateUtilsFragmentTest {
         final long testResult = DateUtils.getFragmentInHours(aDate, Calendar.YEAR);
         final Calendar cal = Calendar.getInstance();
         cal.setTime(aDate);
-        assertEquals(hours + (((cal.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY))
-                        / DateUtils.MILLIS_PER_HOUR,
-                testResult);
+        assertEquals(hours + (cal.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY / DateUtils.MILLIS_PER_HOUR, testResult);
     }
 
-    //Calendar.SECOND as useful fragment
+    // Calendar.SECOND as useful fragment
 
     @Test
     public void testInvalidFragmentWithCalendar() {
@@ -178,7 +170,7 @@ public class DateUtilsFragmentTest {
         assertThrows(IllegalArgumentException.class, () -> DateUtils.getFragmentInDays(aDate, 0));
     }
 
-    //Calendar.MINUTE as useful fragment
+    // Calendar.MINUTE as useful fragment
 
     @Test
     public void testMillisecondFragmentInLargerUnitWithCalendar() {
@@ -201,63 +193,61 @@ public class DateUtilsFragmentTest {
     @Test
     public void testMillisecondsOfDayWithCalendar() {
         long testresult = DateUtils.getFragmentInMilliseconds(aCalendar, Calendar.DATE);
-        final long expectedValue = millis + (seconds * DateUtils.MILLIS_PER_SECOND) + (minutes * DateUtils.MILLIS_PER_MINUTE) + (hours * DateUtils.MILLIS_PER_HOUR);
+        final long expectedValue = millis + seconds * DateUtils.MILLIS_PER_SECOND + minutes * DateUtils.MILLIS_PER_MINUTE + hours * DateUtils.MILLIS_PER_HOUR;
         assertEquals(expectedValue, testresult);
         testresult = DateUtils.getFragmentInMilliseconds(aCalendar, Calendar.DAY_OF_YEAR);
         assertEquals(expectedValue, testresult);
     }
 
-    //Calendar.DATE and Calendar.DAY_OF_YEAR as useful fragment
+    // Calendar.DATE and Calendar.DAY_OF_YEAR as useful fragment
     @Test
     public void testMillisecondsOfDayWithDate() {
         long testresult = DateUtils.getFragmentInMilliseconds(aDate, Calendar.DATE);
-        final long expectedValue = millis + (seconds * DateUtils.MILLIS_PER_SECOND) + (minutes * DateUtils.MILLIS_PER_MINUTE) + (hours * DateUtils.MILLIS_PER_HOUR);
+        final long expectedValue = millis + seconds * DateUtils.MILLIS_PER_SECOND + minutes * DateUtils.MILLIS_PER_MINUTE + hours * DateUtils.MILLIS_PER_HOUR;
         assertEquals(expectedValue, testresult);
         testresult = DateUtils.getFragmentInMilliseconds(aDate, Calendar.DAY_OF_YEAR);
         assertEquals(expectedValue, testresult);
     }
 
-    //Calendar.HOUR_OF_DAY as useful fragment
+    // Calendar.HOUR_OF_DAY as useful fragment
 
     @Test
     public void testMillisecondsOfHourWithCalendar() {
         final long testResult = DateUtils.getFragmentInMilliseconds(aCalendar, Calendar.HOUR_OF_DAY);
-        assertEquals(millis + (seconds * DateUtils.MILLIS_PER_SECOND) + (minutes * DateUtils.MILLIS_PER_MINUTE), testResult);
+        assertEquals(millis + seconds * DateUtils.MILLIS_PER_SECOND + minutes * DateUtils.MILLIS_PER_MINUTE, testResult);
     }
 
     @Test
     public void testMillisecondsOfHourWithDate() {
         final long testResult = DateUtils.getFragmentInMilliseconds(aDate, Calendar.HOUR_OF_DAY);
-        assertEquals(millis + (seconds * DateUtils.MILLIS_PER_SECOND) + (minutes * DateUtils.MILLIS_PER_MINUTE), testResult);
+        assertEquals(millis + seconds * DateUtils.MILLIS_PER_SECOND + minutes * DateUtils.MILLIS_PER_MINUTE, testResult);
     }
 
     @Test
     public void testMillisecondsOfMinuteWithCalender() {
         final long testResult = DateUtils.getFragmentInMilliseconds(aCalendar, Calendar.MINUTE);
-        assertEquals(millis + (seconds * DateUtils.MILLIS_PER_SECOND), testResult);
+        assertEquals(millis + seconds * DateUtils.MILLIS_PER_SECOND, testResult);
     }
 
     @Test
     public void testMillisecondsOfMinuteWithDate() {
         final long testResult = DateUtils.getFragmentInMilliseconds(aDate, Calendar.MINUTE);
-        assertEquals(millis + (seconds * DateUtils.MILLIS_PER_SECOND), testResult);
+        assertEquals(millis + seconds * DateUtils.MILLIS_PER_SECOND, testResult);
     }
 
     @Test
     public void testMillisecondsOfMonthWithCalendar() {
         final long testResult = DateUtils.getFragmentInMilliseconds(aCalendar, Calendar.MONTH);
-        assertEquals(millis + (seconds * DateUtils.MILLIS_PER_SECOND) + (minutes * DateUtils.MILLIS_PER_MINUTE)
-                + (hours * DateUtils.MILLIS_PER_HOUR) + ((days - 1) * DateUtils.MILLIS_PER_DAY),
-testResult);
+        assertEquals(millis + seconds * DateUtils.MILLIS_PER_SECOND + minutes * DateUtils.MILLIS_PER_MINUTE + hours * DateUtils.MILLIS_PER_HOUR
+                + (days - 1) * DateUtils.MILLIS_PER_DAY, testResult);
     }
 
-    //Calendar.MONTH as useful fragment
+    // Calendar.MONTH as useful fragment
     @Test
     public void testMillisecondsOfMonthWithDate() {
         final long testResult = DateUtils.getFragmentInMilliseconds(aDate, Calendar.MONTH);
-        assertEquals(millis + (seconds * DateUtils.MILLIS_PER_SECOND) + (minutes * DateUtils.MILLIS_PER_MINUTE)
-                                + (hours * DateUtils.MILLIS_PER_HOUR) + ((days - 1) * DateUtils.MILLIS_PER_DAY),
-                testResult);
+        assertEquals(millis + seconds * DateUtils.MILLIS_PER_SECOND + minutes * DateUtils.MILLIS_PER_MINUTE + hours * DateUtils.MILLIS_PER_HOUR
+                + (days - 1) * DateUtils.MILLIS_PER_DAY, testResult);
     }
 
     @Test
@@ -276,20 +266,18 @@ testResult);
     @Test
     public void testMillisecondsOfYearWithCalendar() {
         final long testResult = DateUtils.getFragmentInMilliseconds(aCalendar, Calendar.YEAR);
-        assertEquals(millis + (seconds * DateUtils.MILLIS_PER_SECOND) + (minutes * DateUtils.MILLIS_PER_MINUTE)
-                + (hours * DateUtils.MILLIS_PER_HOUR) + ((aCalendar.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY),
-testResult);
+        assertEquals(millis + seconds * DateUtils.MILLIS_PER_SECOND + minutes * DateUtils.MILLIS_PER_MINUTE + hours * DateUtils.MILLIS_PER_HOUR
+                + (aCalendar.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY, testResult);
     }
 
-    //Calendar.YEAR as useful fragment
+    // Calendar.YEAR as useful fragment
     @Test
     public void testMillisecondsOfYearWithDate() {
         final long testResult = DateUtils.getFragmentInMilliseconds(aDate, Calendar.YEAR);
         final Calendar cal = Calendar.getInstance();
         cal.setTime(aDate);
-        assertEquals(millis + (seconds * DateUtils.MILLIS_PER_SECOND) + (minutes * DateUtils.MILLIS_PER_MINUTE)
-                                + (hours * DateUtils.MILLIS_PER_HOUR) + ((cal.get(Calendar.DAY_OF_YEAR) - 1)* DateUtils.MILLIS_PER_DAY),
-                testResult);
+        assertEquals(millis + seconds * DateUtils.MILLIS_PER_SECOND + minutes * DateUtils.MILLIS_PER_MINUTE + hours * DateUtils.MILLIS_PER_HOUR
+                + (cal.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY, testResult);
     }
 
     @Test
@@ -309,7 +297,7 @@ testResult);
     @Test
     public void testMinutesOfDayWithCalendar() {
         long testResult = DateUtils.getFragmentInMinutes(aCalendar, Calendar.DATE);
-        final long expectedValue = minutes + ((hours * DateUtils.MILLIS_PER_HOUR))/ DateUtils.MILLIS_PER_MINUTE;
+        final long expectedValue = minutes + hours * DateUtils.MILLIS_PER_HOUR / DateUtils.MILLIS_PER_MINUTE;
         assertEquals(expectedValue, testResult);
         testResult = DateUtils.getFragmentInMinutes(aCalendar, Calendar.DAY_OF_YEAR);
         assertEquals(expectedValue, testResult);
@@ -318,13 +306,12 @@ testResult);
     @Test
     public void testMinutesOfDayWithDate() {
         long testResult = DateUtils.getFragmentInMinutes(aDate, Calendar.DATE);
-        final long expectedValue = minutes + ((hours * DateUtils.MILLIS_PER_HOUR))/ DateUtils.MILLIS_PER_MINUTE;
+        final long expectedValue = minutes + hours * DateUtils.MILLIS_PER_HOUR / DateUtils.MILLIS_PER_MINUTE;
         assertEquals(expectedValue, testResult);
         testResult = DateUtils.getFragmentInMinutes(aDate, Calendar.DAY_OF_YEAR);
         assertEquals(expectedValue, testResult);
     }
 
-
     @Test
     public void testMinutesOfHourWithCalendar() {
         final long testResult = DateUtils.getFragmentInMinutes(aCalendar, Calendar.HOUR_OF_DAY);
@@ -340,25 +327,20 @@ testResult);
     @Test
     public void testMinutesOfMonthWithCalendar() {
         final long testResult = DateUtils.getFragmentInMinutes(aCalendar, Calendar.MONTH);
-        assertEquals( minutes  +((hours * DateUtils.MILLIS_PER_HOUR) + ((days - 1) * DateUtils.MILLIS_PER_DAY))
-                        / DateUtils.MILLIS_PER_MINUTE,
-                testResult);
+        assertEquals(minutes + (hours * DateUtils.MILLIS_PER_HOUR + (days - 1) * DateUtils.MILLIS_PER_DAY) / DateUtils.MILLIS_PER_MINUTE, testResult);
     }
 
     @Test
     public void testMinutesOfMonthWithDate() {
         final long testResult = DateUtils.getFragmentInMinutes(aDate, Calendar.MONTH);
-        assertEquals(minutes
-                                + ((hours * DateUtils.MILLIS_PER_HOUR) + ((days - 1) * DateUtils.MILLIS_PER_DAY))
-                        / DateUtils.MILLIS_PER_MINUTE,
-                testResult);
+        assertEquals(minutes + (hours * DateUtils.MILLIS_PER_HOUR + (days - 1) * DateUtils.MILLIS_PER_DAY) / DateUtils.MILLIS_PER_MINUTE, testResult);
     }
 
     @Test
     public void testMinutesOfYearWithCalendar() {
         final long testResult = DateUtils.getFragmentInMinutes(aCalendar, Calendar.YEAR);
-        assertEquals( minutes  +((hours * DateUtils.MILLIS_PER_HOUR) + ((aCalendar.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY))
-                        / DateUtils.MILLIS_PER_MINUTE,
+        assertEquals(minutes
+                + (hours * DateUtils.MILLIS_PER_HOUR + (aCalendar.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY) / DateUtils.MILLIS_PER_MINUTE,
                 testResult);
     }
 
@@ -367,9 +349,8 @@ testResult);
         final long testResult = DateUtils.getFragmentInMinutes(aDate, Calendar.YEAR);
         final Calendar cal = Calendar.getInstance();
         cal.setTime(aDate);
-        assertEquals(minutes
-                                + ((hours * DateUtils.MILLIS_PER_HOUR) + ((cal.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY))
-                        / DateUtils.MILLIS_PER_MINUTE,
+        assertEquals(
+                minutes + (hours * DateUtils.MILLIS_PER_HOUR + (cal.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY) / DateUtils.MILLIS_PER_MINUTE,
                 testResult);
     }
 
@@ -383,53 +364,25 @@ testResult);
         c.set(Calendar.SECOND, 0);
         c.set(Calendar.MILLISECOND, 0);
         final long testResult = DateUtils.getFragmentInMinutes(c, Calendar.YEAR);
-        assertEquals( 0, testResult);
+        assertEquals(0, testResult);
     }
 
     @Test
     public void testNullCalendar() {
-        assertThrows(
-                IllegalArgumentException.class,
-                () -> DateUtils.getFragmentInMilliseconds((Calendar) null, Calendar.MILLISECOND));
-
-        assertThrows(
-                IllegalArgumentException.class,
-                () -> DateUtils.getFragmentInSeconds((Calendar) null, Calendar.MILLISECOND));
-
-        assertThrows(
-                IllegalArgumentException.class,
-                () -> DateUtils.getFragmentInMinutes((Calendar) null, Calendar.MILLISECOND));
-
-        assertThrows(
-                IllegalArgumentException.class,
-                () -> DateUtils.getFragmentInHours((Calendar) null, Calendar.MILLISECOND));
-
-        assertThrows(
-                IllegalArgumentException.class,
-                () -> DateUtils.getFragmentInDays((Calendar) null, Calendar.MILLISECOND));
+        assertThrows(NullPointerException.class, () -> DateUtils.getFragmentInMilliseconds((Calendar) null, Calendar.MILLISECOND));
+        assertThrows(NullPointerException.class, () -> DateUtils.getFragmentInSeconds((Calendar) null, Calendar.MILLISECOND));
+        assertThrows(NullPointerException.class, () -> DateUtils.getFragmentInMinutes((Calendar) null, Calendar.MILLISECOND));
+        assertThrows(NullPointerException.class, () -> DateUtils.getFragmentInHours((Calendar) null, Calendar.MILLISECOND));
+        assertThrows(NullPointerException.class, () -> DateUtils.getFragmentInDays((Calendar) null, Calendar.MILLISECOND));
     }
 
     @Test
     public void testNullDate() {
-        assertThrows(
-                NullPointerException.class,
-                () -> DateUtils.getFragmentInMilliseconds((Date) null, Calendar.MILLISECOND));
-
-        assertThrows(
-                NullPointerException.class,
-                () -> DateUtils.getFragmentInSeconds((Date) null, Calendar.MILLISECOND));
-
-        assertThrows(
-                NullPointerException.class,
-                () -> DateUtils.getFragmentInMinutes((Date) null, Calendar.MILLISECOND));
-
-        assertThrows(
-                NullPointerException.class,
-                () -> DateUtils.getFragmentInHours((Date) null, Calendar.MILLISECOND));
-
-        assertThrows(
-                NullPointerException.class,
-                () -> DateUtils.getFragmentInDays((Date) null, Calendar.MILLISECOND));
+        assertThrows(NullPointerException.class, () -> DateUtils.getFragmentInMilliseconds((Date) null, Calendar.MILLISECOND));
+        assertThrows(NullPointerException.class, () -> DateUtils.getFragmentInSeconds((Date) null, Calendar.MILLISECOND));
+        assertThrows(NullPointerException.class, () -> DateUtils.getFragmentInMinutes((Date) null, Calendar.MILLISECOND));
+        assertThrows(NullPointerException.class, () -> DateUtils.getFragmentInHours((Date) null, Calendar.MILLISECOND));
+        assertThrows(NullPointerException.class, () -> DateUtils.getFragmentInDays((Date) null, Calendar.MILLISECOND));
     }
 
     @Test
@@ -451,7 +404,7 @@ testResult);
     @Test
     public void testSecondsOfDayWithCalendar() {
         long testresult = DateUtils.getFragmentInSeconds(aCalendar, Calendar.DATE);
-        final long expectedValue = seconds + ((minutes * DateUtils.MILLIS_PER_MINUTE) + (hours * DateUtils.MILLIS_PER_HOUR))/ DateUtils.MILLIS_PER_SECOND;
+        final long expectedValue = seconds + (minutes * DateUtils.MILLIS_PER_MINUTE + hours * DateUtils.MILLIS_PER_HOUR) / DateUtils.MILLIS_PER_SECOND;
         assertEquals(expectedValue, testresult);
         testresult = DateUtils.getFragmentInSeconds(aCalendar, Calendar.DAY_OF_YEAR);
         assertEquals(expectedValue, testresult);
@@ -460,7 +413,7 @@ testResult);
     @Test
     public void testSecondsOfDayWithDate() {
         long testresult = DateUtils.getFragmentInSeconds(aDate, Calendar.DATE);
-        final long expectedValue = seconds + ((minutes * DateUtils.MILLIS_PER_MINUTE) + (hours * DateUtils.MILLIS_PER_HOUR))/ DateUtils.MILLIS_PER_SECOND;
+        final long expectedValue = seconds + (minutes * DateUtils.MILLIS_PER_MINUTE + hours * DateUtils.MILLIS_PER_HOUR) / DateUtils.MILLIS_PER_SECOND;
         assertEquals(expectedValue, testresult);
         testresult = DateUtils.getFragmentInSeconds(aDate, Calendar.DAY_OF_YEAR);
         assertEquals(expectedValue, testresult);
@@ -469,21 +422,13 @@ testResult);
     @Test
     public void testSecondsofHourWithCalendar() {
         final long testResult = DateUtils.getFragmentInSeconds(aCalendar, Calendar.HOUR_OF_DAY);
-        assertEquals(
-                seconds
-                        + (minutes
-                                * DateUtils.MILLIS_PER_MINUTE / DateUtils.MILLIS_PER_SECOND),
-                testResult);
+        assertEquals(seconds + minutes * DateUtils.MILLIS_PER_MINUTE / DateUtils.MILLIS_PER_SECOND, testResult);
     }
 
     @Test
     public void testSecondsofHourWithDate() {
         final long testResult = DateUtils.getFragmentInSeconds(aDate, Calendar.HOUR_OF_DAY);
-        assertEquals(
-                seconds
-                        + (minutes
-                                * DateUtils.MILLIS_PER_MINUTE / DateUtils.MILLIS_PER_SECOND),
-                testResult);
+        assertEquals(seconds + minutes * DateUtils.MILLIS_PER_MINUTE / DateUtils.MILLIS_PER_SECOND, testResult);
     }
 
     @Test
@@ -502,34 +447,22 @@ testResult);
     @Test
     public void testSecondsOfMonthWithCalendar() {
         final long testResult = DateUtils.getFragmentInSeconds(aCalendar, Calendar.MONTH);
-        assertEquals(
-                seconds
-                        + ((minutes * DateUtils.MILLIS_PER_MINUTE)
-                                + (hours * DateUtils.MILLIS_PER_HOUR) + ((days - 1) * DateUtils.MILLIS_PER_DAY))
-                        / DateUtils.MILLIS_PER_SECOND,
-                testResult);
+        assertEquals(seconds + (minutes * DateUtils.MILLIS_PER_MINUTE + hours * DateUtils.MILLIS_PER_HOUR + (days - 1) * DateUtils.MILLIS_PER_DAY)
+                / DateUtils.MILLIS_PER_SECOND, testResult);
     }
 
     @Test
     public void testSecondsOfMonthWithDate() {
         final long testResult = DateUtils.getFragmentInSeconds(aDate, Calendar.MONTH);
-        assertEquals(
-                seconds
-                        + ((minutes * DateUtils.MILLIS_PER_MINUTE)
-                                + (hours * DateUtils.MILLIS_PER_HOUR) + ((days - 1) * DateUtils.MILLIS_PER_DAY))
-                        / DateUtils.MILLIS_PER_SECOND,
-                testResult);
+        assertEquals(seconds + (minutes * DateUtils.MILLIS_PER_MINUTE + hours * DateUtils.MILLIS_PER_HOUR + (days - 1) * DateUtils.MILLIS_PER_DAY)
+                / DateUtils.MILLIS_PER_SECOND, testResult);
     }
 
     @Test
     public void testSecondsOfYearWithCalendar() {
         final long testResult = DateUtils.getFragmentInSeconds(aCalendar, Calendar.YEAR);
-        assertEquals(
-                seconds
-                        + ((minutes * DateUtils.MILLIS_PER_MINUTE)
-                                + (hours * DateUtils.MILLIS_PER_HOUR) + ((aCalendar.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY))
-                        / DateUtils.MILLIS_PER_SECOND,
-                testResult);
+        assertEquals(seconds + (minutes * DateUtils.MILLIS_PER_MINUTE + hours * DateUtils.MILLIS_PER_HOUR
+                + (aCalendar.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY) / DateUtils.MILLIS_PER_SECOND, testResult);
     }
 
     @Test
@@ -537,10 +470,8 @@ testResult);
         final long testResult = DateUtils.getFragmentInSeconds(aDate, Calendar.YEAR);
         final Calendar cal = Calendar.getInstance();
         cal.setTime(aDate);
-        assertEquals(
-                seconds
-                        + ((minutes * DateUtils.MILLIS_PER_MINUTE)
-                                + (hours * DateUtils.MILLIS_PER_HOUR) + ((cal.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY))
+        assertEquals(seconds
+                + (minutes * DateUtils.MILLIS_PER_MINUTE + hours * DateUtils.MILLIS_PER_HOUR + (cal.get(Calendar.DAY_OF_YEAR) - 1) * DateUtils.MILLIS_PER_DAY)
                         / DateUtils.MILLIS_PER_SECOND,
                 testResult);
     }
