@@ -38,8 +38,6 @@ import org.junit.jupiter.api.Test;
  * A month with 28 days will be rounded up from the 15th
  * A month with 29 or 30 days will be rounded up from the 16th
  * A month with 31 days will be rounded up from the 17th
- *
- * @since 3.0
  */
 public class DateUtilsRoundingTest extends AbstractLangTest {
 
@@ -58,7 +56,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
     @SuppressWarnings("deprecation")
     FastDateFormat fdf = DateFormatUtils.ISO_DATETIME_FORMAT;
 
-
     /**
      * When using this basetest all extremes are tested.<br>
      * It will test the Date, Calendar and Object-implementation<br>
@@ -69,18 +66,17 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * @param roundedDownDate the result if <strong>lastRoundDownDate</strong> was rounded with <strong>calendarField</strong>
      * @param lastRoundDownDate rounding this value with <strong>calendarField</strong> will result in <strong>roundedDownDate</strong>
      * @param calendarField a Calendar.field value
-     * @since 3.0
      */
     protected void baseRoundTest(final Date roundedUpDate, final Date roundedDownDate, final Date lastRoundDownDate, final int calendarField) {
         final Date firstRoundUpDate = DateUtils.addMilliseconds(lastRoundDownDate, 1);
 
-        //Date-comparison
+        // Date-comparison
         assertEquals(roundedDownDate, DateUtils.round(roundedDownDate, calendarField));
         assertEquals(roundedUpDate, DateUtils.round(roundedUpDate, calendarField));
         assertEquals(roundedDownDate, DateUtils.round(lastRoundDownDate, calendarField));
         assertEquals(roundedUpDate, DateUtils.round(firstRoundUpDate, calendarField));
 
-        //Calendar-initiations
+        // Calendar-initiations
         final Calendar roundedUpCalendar;
         final Calendar roundedDownCalendar;
         final Calendar lastRoundDownCalendar;
@@ -94,13 +90,13 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         lastRoundDownCalendar.setTime(lastRoundDownDate);
         firstRoundUpCalendar.setTime(firstRoundUpDate);
 
-        //Calendar-comparison
+        // Calendar-comparison
         assertEquals(roundedDownCalendar, DateUtils.round(roundedDownCalendar, calendarField));
         assertEquals(roundedUpCalendar, DateUtils.round(roundedUpCalendar, calendarField));
         assertEquals(roundedDownCalendar, DateUtils.round(lastRoundDownCalendar, calendarField));
         assertEquals(roundedUpCalendar, DateUtils.round(firstRoundUpCalendar, calendarField));
 
-        //Object-comparison
+        // Object-comparison
         assertEquals(roundedDownDate, DateUtils.round((Object) roundedDownDate, calendarField));
         assertEquals(roundedUpDate, DateUtils.round((Object) roundedUpDate, calendarField));
         assertEquals(roundedDownDate, DateUtils.round((Object) lastRoundDownDate, calendarField));
@@ -120,17 +116,18 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * @param truncatedDate expected Date when <strong>lastTruncateDate</strong> is truncated with <strong>calendarField</strong>
      * @param lastTruncateDate the last possible Date which will truncate to <strong>truncatedDate</strong> with <strong>calendarField</strong>
      * @param calendarField a Calendar.field value
-     * @since 3.0
      */
     protected void baseTruncateTest(final Date truncatedDate, final Date lastTruncateDate, final int calendarField) {
         final Date nextTruncateDate = DateUtils.addMilliseconds(lastTruncateDate, 1);
 
-        //Date-comparison
-        assertEquals(truncatedDate, DateUtils.truncate(truncatedDate, calendarField), "Truncating "+ fdf.format(truncatedDate) +" as Date with CalendarField-value "+ calendarField +" must return itself");
+        // Date-comparison
+        assertEquals(truncatedDate, DateUtils.truncate(truncatedDate, calendarField),
+                "Truncating " + fdf.format(truncatedDate) + " as Date with CalendarField-value " + calendarField + " must return itself");
         assertEquals(truncatedDate, DateUtils.truncate(lastTruncateDate, calendarField));
-        assertNotEquals(truncatedDate, DateUtils.truncate(nextTruncateDate, calendarField), fdf.format(lastTruncateDate) + " is not an extreme when truncating as Date with CalendarField-value " + calendarField);
+        assertNotEquals(truncatedDate, DateUtils.truncate(nextTruncateDate, calendarField),
+                fdf.format(lastTruncateDate) + " is not an extreme when truncating as Date with CalendarField-value " + calendarField);
 
-        //Calendar-initiations
+        // Calendar-initiations
         final Calendar truncatedCalendar;
         final Calendar lastTruncateCalendar;
         final Calendar nextTruncateCalendar;
@@ -141,18 +138,24 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         lastTruncateCalendar.setTime(lastTruncateDate);
         nextTruncateCalendar.setTime(nextTruncateDate);
 
-        //Calendar-comparison
-        assertEquals(truncatedCalendar, DateUtils.truncate(truncatedCalendar, calendarField), "Truncating "+ fdf.format(truncatedCalendar) +" as Calendar with CalendarField-value "+ calendarField +" must return itself");
+        // Calendar-comparison
+        assertEquals(truncatedCalendar, DateUtils.truncate(truncatedCalendar, calendarField),
+                "Truncating " + fdf.format(truncatedCalendar) + " as Calendar with CalendarField-value " + calendarField + " must return itself");
         assertEquals(truncatedCalendar, DateUtils.truncate(lastTruncateCalendar, calendarField));
-        assertNotEquals(truncatedCalendar, DateUtils.truncate(nextTruncateCalendar, calendarField), fdf.format(lastTruncateCalendar) + " is not an extreme when truncating as Calendar with CalendarField-value " + calendarField);
+        assertNotEquals(truncatedCalendar, DateUtils.truncate(nextTruncateCalendar, calendarField),
+                fdf.format(lastTruncateCalendar) + " is not an extreme when truncating as Calendar with CalendarField-value " + calendarField);
 
-        //Object-comparison
-        assertEquals(truncatedDate, DateUtils.truncate((Object) truncatedDate, calendarField), "Truncating "+ fdf.format(truncatedDate) +" as Date cast to Object with CalendarField-value "+ calendarField +" must return itself as Date");
+        // Object-comparison
+        assertEquals(truncatedDate, DateUtils.truncate((Object) truncatedDate, calendarField), "Truncating " + fdf.format(truncatedDate)
+                + " as Date cast to Object with CalendarField-value " + calendarField + " must return itself as Date");
         assertEquals(truncatedDate, DateUtils.truncate((Object) lastTruncateDate, calendarField));
-        assertNotEquals(truncatedDate, DateUtils.truncate((Object) nextTruncateDate, calendarField), fdf.format(lastTruncateDate) + " is not an extreme when truncating as Date cast to Object with CalendarField-value " + calendarField);
-        assertEquals(truncatedDate, DateUtils.truncate((Object) truncatedCalendar, calendarField), "Truncating "+ fdf.format(truncatedCalendar) +" as Calendar cast to Object with CalendarField-value "+ calendarField +" must return itself as Date");
+        assertNotEquals(truncatedDate, DateUtils.truncate((Object) nextTruncateDate, calendarField),
+                fdf.format(lastTruncateDate) + " is not an extreme when truncating as Date cast to Object with CalendarField-value " + calendarField);
+        assertEquals(truncatedDate, DateUtils.truncate((Object) truncatedCalendar, calendarField), "Truncating " + fdf.format(truncatedCalendar)
+                + " as Calendar cast to Object with CalendarField-value " + calendarField + " must return itself as Date");
         assertEquals(truncatedDate, DateUtils.truncate((Object) lastTruncateCalendar, calendarField));
-        assertNotEquals(truncatedDate, DateUtils.truncate((Object) nextTruncateCalendar, calendarField), fdf.format(lastTruncateCalendar) + " is not an extreme when truncating as Calendar cast to Object with CalendarField-value " + calendarField);
+        assertNotEquals(truncatedDate, DateUtils.truncate((Object) nextTruncateCalendar, calendarField),
+                fdf.format(lastTruncateCalendar) + " is not an extreme when truncating as Calendar cast to Object with CalendarField-value " + calendarField);
     }
 
     /**
@@ -163,10 +166,10 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * @param minDate the lower bound
      * @param maxDate the upper bound
      * @param calendarField a Calendar.field value
-     * @since 3.0
      */
     protected void roundToJanuaryFirst(final Date minDate, final Date maxDate, final int calendarField) {
-        assertEquals(januaryOneDate, DateUtils.round(januaryOneDate, calendarField), "Rounding "+ fdf.format(januaryOneDate) +" as Date with CalendarField-value "+ calendarField +" must return itself");
+        assertEquals(januaryOneDate, DateUtils.round(januaryOneDate, calendarField),
+                "Rounding " + fdf.format(januaryOneDate) + " as Date with CalendarField-value " + calendarField + " must return itself");
         assertEquals(januaryOneDate, DateUtils.round(minDate, calendarField));
         assertEquals(januaryOneDate, DateUtils.round(maxDate, calendarField));
 
@@ -174,21 +177,26 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         minCalendar.setTime(minDate);
         final Calendar maxCalendar = Calendar.getInstance();
         maxCalendar.setTime(maxDate);
-        assertEquals(januaryOneCalendar, DateUtils.round(januaryOneCalendar, calendarField), "Rounding "+ fdf.format(januaryOneCalendar) +" as Date with CalendarField-value "+ calendarField +" must return itself");
+        assertEquals(januaryOneCalendar, DateUtils.round(januaryOneCalendar, calendarField),
+                "Rounding " + fdf.format(januaryOneCalendar) + " as Date with CalendarField-value " + calendarField + " must return itself");
         assertEquals(januaryOneCalendar, DateUtils.round(minCalendar, calendarField));
         assertEquals(januaryOneCalendar, DateUtils.round(maxCalendar, calendarField));
 
         final Date toPrevRoundDate = DateUtils.addMilliseconds(minDate, -1);
         final Date toNextRoundDate = DateUtils.addMilliseconds(maxDate, 1);
-        assertNotEquals(januaryOneDate, DateUtils.round(toPrevRoundDate, calendarField), fdf.format(minDate) + " is not an lower-extreme when rounding as Date with CalendarField-value " + calendarField);
-        assertNotEquals(januaryOneDate, DateUtils.round(toNextRoundDate, calendarField), fdf.format(maxDate) + " is not an upper-extreme when rounding as Date with CalendarField-value " + calendarField);
+        assertNotEquals(januaryOneDate, DateUtils.round(toPrevRoundDate, calendarField),
+                fdf.format(minDate) + " is not an lower-extreme when rounding as Date with CalendarField-value " + calendarField);
+        assertNotEquals(januaryOneDate, DateUtils.round(toNextRoundDate, calendarField),
+                fdf.format(maxDate) + " is not an upper-extreme when rounding as Date with CalendarField-value " + calendarField);
 
         final Calendar toPrevRoundCalendar = Calendar.getInstance();
         toPrevRoundCalendar.setTime(toPrevRoundDate);
         final Calendar toNextRoundCalendar = Calendar.getInstance();
         toNextRoundCalendar.setTime(toNextRoundDate);
-        assertNotEquals(januaryOneDate, DateUtils.round(toPrevRoundDate, calendarField), fdf.format(minCalendar) + " is not an lower-extreme when rounding as Date with CalendarField-value " + calendarField);
-        assertNotEquals(januaryOneDate, DateUtils.round(toNextRoundDate, calendarField), fdf.format(maxCalendar) + " is not an upper-extreme when rounding as Date with CalendarField-value " + calendarField);
+        assertNotEquals(januaryOneDate, DateUtils.round(toPrevRoundDate, calendarField),
+                fdf.format(minCalendar) + " is not an lower-extreme when rounding as Date with CalendarField-value " + calendarField);
+        assertNotEquals(januaryOneDate, DateUtils.round(toNextRoundDate, calendarField),
+                fdf.format(maxCalendar) + " is not an upper-extreme when rounding as Date with CalendarField-value " + calendarField);
     }
 
     @BeforeEach
@@ -198,13 +206,13 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
 
         targetYearDate = dateTimeParser.parse("January 1, 2007 0:00:00.000");
         targetDateDate = targetDayOfMonthDate = dateTimeParser.parse("June 1, 2008 0:00:00.000");
-        targetAmDate =  dateTimeParser.parse("June 1, 2008 0:00:00.000");
+        targetAmDate = dateTimeParser.parse("June 1, 2008 0:00:00.000");
         targetPmDate = dateTimeParser.parse("June 1, 2008 12:00:00.000");
         targetHourDate = dateTimeParser.parse("June 1, 2008 8:00:00.000");
         targetHourOfDayDate = dateTimeParser.parse("June 1, 2008 8:00:00.000");
-        targetMinuteDate =  dateTimeParser.parse("June 1, 2008 8:15:00.000");
-        targetSecondDate =  dateTimeParser.parse("June 1, 2008 8:15:14.000");
-        targetMilliSecondDate =  dateTimeParser.parse("June 1, 2008 8:15:14.231");
+        targetMinuteDate = dateTimeParser.parse("June 1, 2008 8:15:00.000");
+        targetSecondDate = dateTimeParser.parse("June 1, 2008 8:15:14.000");
+        targetMilliSecondDate = dateTimeParser.parse("June 1, 2008 8:15:14.231");
 
         januaryOneDate = dateTimeParser.parse("January 1, 2008 0:00:00.000");
         januaryOneCalendar = Calendar.getInstance();
@@ -217,7 +225,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Includes rounding to January 1
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testRoundAmPm() throws Exception {
@@ -226,19 +233,19 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         final Date minDate;
         final Date maxDate;
 
-        //AM
+        // AM
         roundedUpDate = dateTimeParser.parse("June 1, 2008 12:00:00.000");
         roundedDownDate = targetAmDate;
         lastRoundedDownDate = dateTimeParser.parse("June 1, 2008 5:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //PM
+        // PM
         roundedUpDate = dateTimeParser.parse("June 2, 2008 0:00:00.000");
         roundedDownDate = targetPmDate;
         lastRoundedDownDate = dateTimeParser.parse("June 1, 2008 17:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //round to January 1
+        // round to January 1
         minDate = dateTimeParser.parse("December 31, 2007 18:00:00.000");
         maxDate = dateTimeParser.parse("January 1, 2008 5:59:59.999");
         roundToJanuaryFirst(minDate, maxDate, calendarField);
@@ -250,7 +257,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Includes rounding to January 1
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testRoundDate() throws Exception {
@@ -264,9 +270,9 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         roundedUpDate = dateTimeParser.parse("June 2, 2008 0:00:00.000");
         roundedDownDate = targetDateDate;
         lastRoundedDownDate = dateTimeParser.parse("June 1, 2008 11:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //round to January 1
+        // round to January 1
         minDate = dateTimeParser.parse("December 31, 2007 12:00:00.000");
         maxDate = dateTimeParser.parse("January 1, 2008 11:59:59.999");
         roundToJanuaryFirst(minDate, maxDate, calendarField);
@@ -278,7 +284,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Includes rounding to January 1
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testRoundDayOfMonth() throws Exception {
@@ -292,9 +297,9 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         roundedUpDate = dateTimeParser.parse("June 2, 2008 0:00:00.000");
         roundedDownDate = targetDayOfMonthDate;
         lastRoundedDownDate = dateTimeParser.parse("June 1, 2008 11:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //round to January 1
+        // round to January 1
         minDate = dateTimeParser.parse("December 31, 2007 12:00:00.000");
         maxDate = dateTimeParser.parse("January 1, 2008 11:59:59.999");
         roundToJanuaryFirst(minDate, maxDate, calendarField);
@@ -306,7 +311,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Includes rounding to January 1
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testRoundHour() throws Exception {
@@ -320,9 +324,9 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         roundedUpDate = dateTimeParser.parse("June 1, 2008 9:00:00.000");
         roundedDownDate = targetHourDate;
         lastRoundedDownDate = dateTimeParser.parse("June 1, 2008 8:29:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //round to January 1
+        // round to January 1
         minDate = dateTimeParser.parse("December 31, 2007 23:30:00.000");
         maxDate = dateTimeParser.parse("January 1, 2008 0:29:59.999");
         roundToJanuaryFirst(minDate, maxDate, calendarField);
@@ -334,7 +338,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Includes rounding to January 1
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testRoundHourOfDay() throws Exception {
@@ -348,9 +351,9 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         roundedUpDate = dateTimeParser.parse("June 1, 2008 9:00:00.000");
         roundedDownDate = targetHourOfDayDate;
         lastRoundedDownDate = dateTimeParser.parse("June 1, 2008 8:29:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //round to January 1
+        // round to January 1
         minDate = dateTimeParser.parse("December 31, 2007 23:30:00.000");
         maxDate = dateTimeParser.parse("January 1, 2008 0:29:59.999");
         roundToJanuaryFirst(minDate, maxDate, calendarField);
@@ -362,7 +365,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Includes rounding to January 1
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testRoundMilliSecond() throws Exception {
@@ -375,9 +377,9 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
 
         roundedDownDate = lastRoundedDownDate = targetMilliSecondDate;
         roundedUpDate = dateTimeParser.parse("June 1, 2008 8:15:14.232");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //round to January 1
+        // round to January 1
         minDate = maxDate = januaryOneDate;
         roundToJanuaryFirst(minDate, maxDate, calendarField);
     }
@@ -388,7 +390,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Includes rounding to January 1
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testRoundMinute() throws Exception {
@@ -402,9 +403,9 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         roundedUpDate = dateTimeParser.parse("June 1, 2008 8:16:00.000");
         roundedDownDate = targetMinuteDate;
         lastRoundedDownDate = dateTimeParser.parse("June 1, 2008 8:15:29.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //round to January 1
+        // round to January 1
         minDate = dateTimeParser.parse("December 31, 2007 23:59:30.000");
         maxDate = dateTimeParser.parse("January 1, 2008 0:00:29.999");
         roundToJanuaryFirst(minDate, maxDate, calendarField);
@@ -416,7 +417,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Includes rounding to January 1
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testRoundMonth() throws Exception {
@@ -425,31 +425,31 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         final Date minDate;
         final Date maxDate;
 
-        //month with 28 days
+        // month with 28 days
         roundedUpDate = dateTimeParser.parse("March 1, 2007 0:00:00.000");
         roundedDownDate = dateTimeParser.parse("February 1, 2007 0:00:00.000");
         lastRoundedDownDate = dateTimeParser.parse("February 14, 2007 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //month with 29 days
+        // month with 29 days
         roundedUpDate = dateTimeParser.parse("March 1, 2008 0:00:00.000");
         roundedDownDate = dateTimeParser.parse("February 1, 2008 0:00:00.000");
         lastRoundedDownDate = dateTimeParser.parse("February 15, 2008 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //month with 30 days
+        // month with 30 days
         roundedUpDate = dateTimeParser.parse("May 1, 2008 0:00:00.000");
         roundedDownDate = dateTimeParser.parse("April 1, 2008 0:00:00.000");
         lastRoundedDownDate = dateTimeParser.parse("April 15, 2008 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //month with 31 days
+        // month with 31 days
         roundedUpDate = dateTimeParser.parse("June 1, 2008 0:00:00.000");
         roundedDownDate = dateTimeParser.parse("May 1, 2008 0:00:00.000");
         lastRoundedDownDate = dateTimeParser.parse("May 16, 2008 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //round to January 1
+        // round to January 1
         minDate = dateTimeParser.parse("December 17, 2007 00:00:00.000");
         maxDate = dateTimeParser.parse("January 16, 2008 23:59:59.999");
         roundToJanuaryFirst(minDate, maxDate, calendarField);
@@ -461,7 +461,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Includes rounding to January 1
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testRoundSecond() throws Exception {
@@ -475,9 +474,9 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         roundedUpDate = dateTimeParser.parse("June 1, 2008 8:15:15.000");
         roundedDownDate = targetSecondDate;
         lastRoundedDownDate = dateTimeParser.parse("June 1, 2008 8:15:14.499");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //round to January 1
+        // round to January 1
         minDate = dateTimeParser.parse("December 31, 2007 23:59:59.500");
         maxDate = dateTimeParser.parse("January 1, 2008 0:00:00.499");
         roundToJanuaryFirst(minDate, maxDate, calendarField);
@@ -489,7 +488,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Includes rounding to January 1
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testRoundSemiMonth() throws Exception {
@@ -498,55 +496,55 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         final Date minDate;
         final Date maxDate;
 
-        //month with 28 days (1)
+        // month with 28 days (1)
         roundedUpDate = dateTimeParser.parse("February 16, 2007 0:00:00.000");
         roundedDownDate = dateTimeParser.parse("February 1, 2007 0:00:00.000");
         lastRoundedDownDate = dateTimeParser.parse("February 8, 2007 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //month with 28 days (2)
+        // month with 28 days (2)
         roundedUpDate = dateTimeParser.parse("March 1, 2007 0:00:00.000");
         roundedDownDate = dateTimeParser.parse("February 16, 2007 0:00:00.000");
         lastRoundedDownDate = dateTimeParser.parse("February 23, 2007 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //month with 29 days (1)
+        // month with 29 days (1)
         roundedUpDate = dateTimeParser.parse("February 16, 2008 0:00:00.000");
         roundedDownDate = dateTimeParser.parse("February 1, 2008 0:00:00.000");
         lastRoundedDownDate = dateTimeParser.parse("February 8, 2008 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //month with 29 days (2)
+        // month with 29 days (2)
         roundedUpDate = dateTimeParser.parse("March 1, 2008 0:00:00.000");
         roundedDownDate = dateTimeParser.parse("February 16, 2008 0:00:00.000");
         lastRoundedDownDate = dateTimeParser.parse("February 23, 2008 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //month with 30 days (1)
+        // month with 30 days (1)
         roundedUpDate = dateTimeParser.parse("April 16, 2008 0:00:00.000");
         roundedDownDate = dateTimeParser.parse("April 1, 2008 0:00:00.000");
         lastRoundedDownDate = dateTimeParser.parse("April 8, 2008 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //month with 30 days (2)
+        // month with 30 days (2)
         roundedUpDate = dateTimeParser.parse("May 1, 2008 0:00:00.000");
         roundedDownDate = dateTimeParser.parse("April 16, 2008 0:00:00.000");
         lastRoundedDownDate = dateTimeParser.parse("April 23, 2008 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //month with 31 days (1)
+        // month with 31 days (1)
         roundedUpDate = dateTimeParser.parse("May 16, 2008 0:00:00.000");
         roundedDownDate = dateTimeParser.parse("May 1, 2008 0:00:00.000");
         lastRoundedDownDate = dateTimeParser.parse("May 8, 2008 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //month with 31 days (2)
+        // month with 31 days (2)
         roundedUpDate = dateTimeParser.parse("June 1, 2008 0:00:00.000");
         roundedDownDate = dateTimeParser.parse("May 16, 2008 0:00:00.000");
         lastRoundedDownDate = dateTimeParser.parse("May 23, 2008 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
 
-        //round to January 1
+        // round to January 1
         minDate = dateTimeParser.parse("December 24, 2007 00:00:00.000");
         maxDate = dateTimeParser.parse("January 8, 2008 23:59:59.999");
         roundToJanuaryFirst(minDate, maxDate, calendarField);
@@ -556,7 +554,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Tests DateUtils.round()-method with Calendar.Year
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testRoundYear() throws Exception {
@@ -564,7 +561,7 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
         final Date roundedUpDate = dateTimeParser.parse("January 1, 2008 0:00:00.000");
         final Date roundedDownDate = targetYearDate;
         final Date lastRoundedDownDate = dateTimeParser.parse("June 30, 2007 23:59:59.999");
-        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate,  calendarField);
+        baseRoundTest(roundedUpDate, roundedDownDate, lastRoundedDownDate, calendarField);
     }
 
     /**
@@ -572,17 +569,14 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Includes truncating the extremes of both AM and PM of one day
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testTruncateAmPm() throws Exception {
         final int calendarField = Calendar.AM_PM;
-
-        //AM
+        // AM
         Date lastTruncateDate = dateTimeParser.parse("June 1, 2008 11:59:59.999");
         baseTruncateTest(targetAmDate, lastTruncateDate, calendarField);
-
-        //PM
+        // PM
         lastTruncateDate = dateTimeParser.parse("June 1, 2008 23:59:59.999");
         baseTruncateTest(targetPmDate, lastTruncateDate, calendarField);
     }
@@ -591,7 +585,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Test DateUtils.truncate()-method with Calendar.DATE
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testTruncateDate() throws Exception {
@@ -604,7 +597,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Test DateUtils.truncate()-method with Calendar.DAY_OF_MONTH
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testTruncateDayOfMonth() throws Exception {
@@ -617,7 +609,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Test DateUtils.truncate()-method with Calendar.HOUR
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testTruncateHour() throws Exception {
@@ -630,7 +621,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Test DateUtils.truncate()-method with Calendar.HOUR_OF_DAY
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testTruncateHourOfDay() throws Exception {
@@ -641,8 +631,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
 
     /**
      * Test DateUtils.truncate()-method with Calendar.SECOND
-     *
-     * @since 3.0
      */
     @Test
     public void testTruncateMilliSecond() {
@@ -654,7 +642,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Test DateUtils.truncate()-method with Calendar.MINUTE
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testTruncateMinute() throws Exception {
@@ -667,7 +654,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Test DateUtils.truncate()-method with Calendar.MONTH
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testTruncateMonth() throws Exception {
@@ -681,7 +667,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Test DateUtils.truncate()-method with Calendar.SECOND
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testTruncateSecond() throws Exception {
@@ -695,49 +680,48 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Includes truncating months with 28, 29, 30 and 31 days, each with first and second half
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testTruncateSemiMonth() throws Exception {
         final int calendarField = DateUtils.SEMI_MONTH;
         Date truncatedDate, lastTruncateDate;
 
-        //month with 28 days (1)
+        // month with 28 days (1)
         truncatedDate = dateTimeParser.parse("February 1, 2007 0:00:00.000");
         lastTruncateDate = dateTimeParser.parse("February 15, 2007 23:59:59.999");
         baseTruncateTest(truncatedDate, lastTruncateDate, calendarField);
 
-        //month with 28 days (2)
+        // month with 28 days (2)
         truncatedDate = dateTimeParser.parse("February 16, 2007 0:00:00.000");
         lastTruncateDate = dateTimeParser.parse("February 28, 2007 23:59:59.999");
         baseTruncateTest(truncatedDate, lastTruncateDate, calendarField);
 
-        //month with 29 days (1)
+        // month with 29 days (1)
         truncatedDate = dateTimeParser.parse("February 1, 2008 0:00:00.000");
         lastTruncateDate = dateTimeParser.parse("February 15, 2008 23:59:59.999");
         baseTruncateTest(truncatedDate, lastTruncateDate, calendarField);
 
-        //month with 29 days (2)
+        // month with 29 days (2)
         truncatedDate = dateTimeParser.parse("February 16, 2008 0:00:00.000");
         lastTruncateDate = dateTimeParser.parse("February 29, 2008 23:59:59.999");
         baseTruncateTest(truncatedDate, lastTruncateDate, calendarField);
 
-        //month with 30 days (1)
+        // month with 30 days (1)
         truncatedDate = dateTimeParser.parse("April 1, 2008 0:00:00.000");
         lastTruncateDate = dateTimeParser.parse("April 15, 2008 23:59:59.999");
         baseTruncateTest(truncatedDate, lastTruncateDate, calendarField);
 
-        //month with 30 days (2)
+        // month with 30 days (2)
         truncatedDate = dateTimeParser.parse("April 16, 2008 0:00:00.000");
         lastTruncateDate = dateTimeParser.parse("April 30, 2008 23:59:59.999");
         baseTruncateTest(truncatedDate, lastTruncateDate, calendarField);
 
-        //month with 31 days (1)
+        // month with 31 days (1)
         truncatedDate = dateTimeParser.parse("March 1, 2008 0:00:00.000");
         lastTruncateDate = dateTimeParser.parse("March 15, 2008 23:59:59.999");
         baseTruncateTest(truncatedDate, lastTruncateDate, calendarField);
 
-        //month with 31 days (2)
+        // month with 31 days (2)
         truncatedDate = dateTimeParser.parse("March 16, 2008 0:00:00.000");
         lastTruncateDate = dateTimeParser.parse("March 31, 2008 23:59:59.999");
         baseTruncateTest(truncatedDate, lastTruncateDate, calendarField);
@@ -748,7 +732,6 @@ public class DateUtilsRoundingTest extends AbstractLangTest {
      * Test DateUtils.truncate()-method with Calendar.YEAR
      *
      * @throws Exception so we don't have to catch it
-     * @since 3.0
      */
     @Test
     public void testTruncateYear() throws Exception {
