@@ -31,6 +31,7 @@ import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.time.Duration;
+import java.time.Instant;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.commons.lang3.AbstractLangTest;
@@ -72,6 +73,10 @@ public class StopWatchTest extends AbstractLangTest {
     private StopWatch createMockStopWatch(final long nanos) {
         final StopWatch watch = StopWatch.createStarted();
         watch.suspend();
+        return set(watch, nanos);
+    }
+
+    private StopWatch set(final StopWatch watch, final long nanos) {
         try {
             final long currentNanos = System.nanoTime();
             FieldUtils.writeField(watch, "startTimeNanos", currentNanos - nanos, true);
@@ -86,7 +91,9 @@ public class StopWatchTest extends AbstractLangTest {
         ThreadUtils.sleep(duration);
     }
 
-    // test bad states
+    /**
+     * Tests bad states.
+     */
     @Test
     public void testBadStates() {
         final StopWatch watch = new StopWatch();
@@ -114,7 +121,10 @@ public class StopWatchTest extends AbstractLangTest {
             "Calling unsplit on an unsplit StopWatch should throw an exception. ");
 
         assertThrows(IllegalStateException.class, watch::getSplitTime,
-            "Calling getSplitTime on an unsplit StopWatch should throw an exception. ");
+                "Calling getSplitTime on an unsplit StopWatch should throw an exception. ");
+
+        assertThrows(IllegalStateException.class, watch::getSplitDuration,
+                "Calling getSplitTime on an unsplit StopWatch should throw an exception. ");
 
         assertThrows(IllegalStateException.class, watch::resume,
             "Calling resume on an unsuspended StopWatch should throw an exception. ");
@@ -184,20 +194,80 @@ public class StopWatchTest extends AbstractLangTest {
         assertThat("formatTime", formatTime, not(startsWith(MESSAGE)));
     }
 
+    @Test
+    public void testGetDuration() throws InterruptedException {
+        final StopWatch watch = new StopWatch();
+        assertEquals(Duration.ZERO, watch.getDuration());
+        assertEquals(ZERO_TIME_ELAPSED, watch.toString());
+        watch.start();
+        sleep(MILLIS_550);
+        assertThat("watch.getDuration()", watch.getDuration().toMillis(), lessThan(2000L));
+    }
+
+    @Test
+    public void testGetSplitDuration() {
+        // Create a mock StopWatch with a time of 2:59:01.999
+        // @formatter:off
+        final StopWatch watch = StopWatch.createStarted();
+        watch.split();
+        set(watch, 123456);
+        // @formatter:on
+        assertEquals(Duration.ofNanos(123456), watch.getSplitDuration());
+    }
+
+    @Test
+    public void testGetStartInstant() {
+        final long beforeStopWatchMillis = System.currentTimeMillis();
+        final StopWatch watch = new StopWatch();
+        assertThrows(IllegalStateException.class, watch::getStartInstant, "Calling getStartInstant on an unstarted StopWatch should throw an exception");
+        watch.start();
+
+        watch.getStartInstant();
+        assertThat("getStartInstant", watch.getStartInstant(), greaterThanOrEqualTo(Instant.ofEpochMilli(beforeStopWatchMillis)));
+
+        watch.reset();
+        assertThrows(IllegalStateException.class, watch::getStartInstant,
+                "Calling getStartInstant on a reset, but unstarted StopWatch should throw an exception");
+    }
+
     @Test
     public void testGetStartTime() {
         final long beforeStopWatchMillis = System.currentTimeMillis();
         final StopWatch watch = new StopWatch();
-        assertThrows(IllegalStateException.class, watch::getStartTime,
-            "Calling getStartTime on an unstarted StopWatch should throw an exception");
+        assertThrows(IllegalStateException.class, watch::getStartTime, "Calling getStartTime on an unstarted StopWatch should throw an exception");
         watch.start();
 
         watch.getStartTime();
         assertThat("getStartTime", watch.getStartTime(), greaterThanOrEqualTo(beforeStopWatchMillis));
 
         watch.reset();
-        assertThrows(IllegalStateException.class, watch::getStartTime,
-            "Calling getStartTime on a reset, but unstarted StopWatch should throw an exception");
+        assertThrows(IllegalStateException.class, watch::getStartTime, "Calling getStartTime on a reset, but unstarted StopWatch should throw an exception");
+    }
+
+    @Test
+    public void testGetTime() throws InterruptedException {
+        final StopWatch watch = new StopWatch();
+        assertEquals(0, watch.getTime());
+        assertEquals(ZERO_TIME_ELAPSED, watch.toString());
+        watch.start();
+        sleep(MILLIS_550);
+        assertThat("watch.getTime()", watch.getTime(), lessThan(2000L));
+    }
+
+    @Test
+    public void testGetWithTimeUnit() {
+        // Create a mock StopWatch with a time of 2:59:01.999
+        // @formatter:off
+        final StopWatch watch = createMockStopWatch(
+            TimeUnit.HOURS.toNanos(2)
+                    + TimeUnit.MINUTES.toNanos(59)
+                    + TimeUnit.SECONDS.toNanos(1)
+                    + TimeUnit.MILLISECONDS.toNanos(999));
+        // @formatter:on
+        assertEquals(2L, watch.getTime(TimeUnit.HOURS));
+        assertEquals(179L, watch.getTime(TimeUnit.MINUTES));
+        assertEquals(10741L, watch.getTime(TimeUnit.SECONDS));
+        assertEquals(10741999L, watch.getTime(TimeUnit.MILLISECONDS));
     }
 
     @Test
@@ -206,10 +276,13 @@ public class StopWatchTest extends AbstractLangTest {
         sleep(MILLIS_200);
         watch.suspend();
         final long suspendTime = watch.getTime();
+        final Duration suspendDuration = watch.getDuration();
         sleep(MILLIS_200);
         watch.stop();
         final long totalTime = watch.getTime();
+        final Duration totalDuration = watch.getDuration();
         assertEquals(suspendTime, totalTime);
+        assertEquals(suspendDuration, totalDuration);
     }
 
     @Test
@@ -223,6 +296,65 @@ public class StopWatchTest extends AbstractLangTest {
         assertThat("stopWatch.toSplitString", stopWatch.toSplitString(), startsWith(MESSAGE));
     }
 
+    @Test
+    public void testSimple() throws InterruptedException {
+        final StopWatch watch = StopWatch.createStarted();
+        sleep(MILLIS_550);
+        watch.stop();
+        final long time = watch.getTime();
+        final Duration duration = watch.getDuration();
+        assertEquals(time, watch.getTime());
+        assertEquals(duration, watch.getDuration());
+        assertThat("time", time, allOf(greaterThanOrEqualTo(500L), lessThan(2000L)));
+        assertThat("duration", duration.toMillis(), allOf(greaterThanOrEqualTo(500L), lessThan(2000L)));
+        watch.reset();
+        assertEquals(0, watch.getTime());
+        assertEquals(Duration.ZERO, watch.getDuration());
+    }
+
+    @Test
+    public void testSplit() throws InterruptedException {
+        final StopWatch watch = StopWatch.createStarted();
+        sleep(MILLIS_550);
+        // slept ~550 millis
+        watch.split();
+        final long splitTime = watch.getSplitTime();
+        final Duration splitDuration = watch.getSplitDuration();
+        assertEquals(splitTime, watch.getSplitDuration().toMillis());
+        assertEquals(12, watch.toSplitString().length(), "Formatted split string not the correct length");
+        sleep(MILLIS_550);
+        // slept ~1100 millis
+        watch.unsplit();
+        sleep(MILLIS_550);
+        // slept ~1650 millis
+        watch.stop();
+        final long totalTime = watch.getTime();
+        final Duration totalDuration = watch.getDuration();
+        assertThat("splitTime", splitTime, allOf(greaterThanOrEqualTo(500L), lessThan(1000L)));
+        assertThat("splitDuration", splitDuration.toMillis(), allOf(greaterThanOrEqualTo(500L), lessThan(1000L)));
+        assertThat("totalTime", totalTime, allOf(greaterThanOrEqualTo(1500L), lessThan(2100L)));
+        assertThat("totalDuration", totalDuration.toMillis(), allOf(greaterThanOrEqualTo(1500L), lessThan(2100L)));
+    }
+
+    @Test
+    public void testStatic() {
+        final StopWatch watch = StopWatch.createStarted();
+        assertTrue(watch.isStarted());
+    }
+
+    @Test
+    public void testStopInstantSimple() throws InterruptedException {
+        final StopWatch watch = StopWatch.createStarted();
+        final long testStartMillis = System.currentTimeMillis();
+        sleep(MILLIS_550);
+        watch.stop();
+        final long testEndMillis = System.currentTimeMillis();
+        final Instant stopTime = watch.getStopInstant();
+        assertEquals(stopTime, watch.getStopInstant());
+        assertThat("stopTime", stopTime,
+                allOf(greaterThanOrEqualTo(Instant.ofEpochMilli(testStartMillis)), lessThanOrEqualTo(Instant.ofEpochMilli(testEndMillis))));
+    }
+
     @Test
     public void testStopTimeSimple() throws InterruptedException {
         final StopWatch watch = StopWatch.createStarted();
@@ -232,104 +364,48 @@ public class StopWatchTest extends AbstractLangTest {
         final long testEndMillis = System.currentTimeMillis();
         final long stopTime = watch.getStopTime();
         assertEquals(stopTime, watch.getStopTime());
-
         assertThat("stopTime", stopTime, allOf(greaterThanOrEqualTo(testStartMillis), lessThanOrEqualTo(testEndMillis)));
     }
 
     @Test
-    public void testStopWatchGetWithTimeUnit() {
-        // Create a mock StopWatch with a time of 2:59:01.999
-        // @formatter:off
-        final StopWatch watch = createMockStopWatch(
-            TimeUnit.HOURS.toNanos(2)
-                    + TimeUnit.MINUTES.toNanos(59)
-                    + TimeUnit.SECONDS.toNanos(1)
-                    + TimeUnit.MILLISECONDS.toNanos(999));
-        // @formatter:on
-
-        assertEquals(2L, watch.getTime(TimeUnit.HOURS));
-        assertEquals(179L, watch.getTime(TimeUnit.MINUTES));
-        assertEquals(10741L, watch.getTime(TimeUnit.SECONDS));
-        assertEquals(10741999L, watch.getTime(TimeUnit.MILLISECONDS));
-    }
-
-    @Test
-    public void testStopWatchSimple() throws InterruptedException {
-        final StopWatch watch = StopWatch.createStarted();
-        sleep(MILLIS_550);
-        watch.stop();
-        final long time = watch.getTime();
-        assertEquals(time, watch.getTime());
-
-        assertThat("time", time, allOf(greaterThanOrEqualTo(500L), lessThan(700L)));
-
-        watch.reset();
-        assertEquals(0, watch.getTime());
-    }
-
-    @Test
-    public void testStopWatchSimpleGet() throws InterruptedException {
-        final StopWatch watch = new StopWatch();
-        assertEquals(0, watch.getTime());
-        assertEquals(ZERO_TIME_ELAPSED, watch.toString());
-
-        watch.start();
-        sleep(MILLIS_550);
-        assertThat("watch.getTime()", watch.getTime(), lessThan(2000L));
-    }
-
-    @Test
-    public void testStopWatchSplit() throws InterruptedException {
-        final StopWatch watch = StopWatch.createStarted();
-        sleep(MILLIS_550);
-        watch.split();
-        final long splitTime = watch.getSplitTime();
-        final String splitStr = watch.toSplitString();
-        sleep(MILLIS_550);
-        watch.unsplit();
-        sleep(MILLIS_550);
-        watch.stop();
-        final long totalTime = watch.getTime();
-
-        assertEquals(12, splitStr.length(), "Formatted split string not the correct length");
-        assertThat("splitTime", splitTime, allOf(greaterThanOrEqualTo(500L), lessThan(700L)));
-        assertThat("totalTime", totalTime, allOf(greaterThanOrEqualTo(1500L), lessThan(2000L)));
-    }
-
-    @Test
-    public void testStopWatchStatic() {
-        final StopWatch watch = StopWatch.createStarted();
-        assertTrue(watch.isStarted());
-    }
-
-    @Test
-    public void testStopWatchSuspend() throws InterruptedException {
+    public void testSuspend() throws InterruptedException {
         // Watch out comparing measurements from System.currentTimeMillis() vs. System.nanoTime()
         final StopWatch watch = StopWatch.createStarted();
         final long testStartMillis = System.currentTimeMillis();
         final long testStartNanos = System.nanoTime();
+        final Instant testStartInstant = Instant.ofEpochMilli(testStartMillis);
         sleep(MILLIS_550);
         watch.suspend();
         final long testSuspendMillis = System.currentTimeMillis();
         final long testSuspendNanos = System.nanoTime();
         final long testSuspendTimeNanos = testSuspendNanos - testStartNanos;
+        final Duration testSuspendDuration = Duration.ofNanos(testSuspendTimeNanos);
         final long suspendTimeFromNanos = watch.getTime();
+        final Duration suspendDuration = watch.getDuration();
         final long stopTimeMillis = watch.getStopTime();
+        final Instant stopInstant = watch.getStopInstant();
 
         assertThat("testStartMillis <= stopTimeMillis", testStartMillis, lessThanOrEqualTo(stopTimeMillis));
+        assertThat("testStartInstant <= stopInstant", testStartInstant, lessThanOrEqualTo(stopInstant));
         assertThat("testSuspendMillis <= stopTimeMillis", testSuspendMillis, lessThanOrEqualTo(stopTimeMillis));
+        assertThat("testSuspendMillis <= stopInstant", testSuspendMillis, lessThanOrEqualTo(stopInstant.toEpochMilli()));
 
         sleep(MILLIS_550);
         watch.resume();
         sleep(MILLIS_550);
         watch.stop();
         final long totalTimeFromNanos = watch.getTime();
+        final Duration totalDuration = watch.getDuration();
 
         assertThat("suspendTimeFromNanos", suspendTimeFromNanos, greaterThanOrEqualTo(500L));
+        assertThat("suspendDuration", suspendDuration, greaterThanOrEqualTo(Duration.ofMillis(500L)));
         assertThat("suspendTimeFromNanos <= testSuspendTimeNanos", suspendTimeFromNanos, lessThanOrEqualTo(testSuspendTimeNanos));
+        assertThat("suspendDuration <= testSuspendDuration", suspendDuration, lessThanOrEqualTo(testSuspendDuration));
         assertThat("totalTimeFromNanos", totalTimeFromNanos, greaterThanOrEqualTo(1000L));
+        assertThat("totalDuration", totalDuration, greaterThanOrEqualTo(Duration.ofMillis(1000L)));
         // Be lenient for slow running builds
         assertThat("totalTimeFromNanos", totalTimeFromNanos, lessThan(2500L));
+        assertThat("totalDuration", totalDuration, lessThan(Duration.ofMillis(2500L)));
     }
 
     @Test
