@@ -18,17 +18,19 @@ package org.apache.commons.lang3.tuple;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.Calendar;
 import java.util.HashSet;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.junit.jupiter.api.Test;
 
 /**
  * Test the Triple class.
  */
-public class TripleTest {
+public class TripleTest extends AbstractLangTest {
 
     @Test
     public void testComparable1() {
@@ -106,6 +108,19 @@ public class TripleTest {
         assertEquals("(Key,Something,Value)", String.format("%1$s", triple));
     }
 
+    @Test
+    public void testOfNonNull() {
+        assertThrows(NullPointerException.class, () -> Triple.ofNonNull(null, null, null));
+        assertThrows(NullPointerException.class, () -> Triple.ofNonNull(null, null, "z"));
+        assertThrows(NullPointerException.class, () -> Triple.ofNonNull(null, "y", "z"));
+        assertThrows(NullPointerException.class, () -> Triple.ofNonNull("x", null, null));
+        assertThrows(NullPointerException.class, () -> Triple.ofNonNull("x", "y", null));
+        final Triple<String, String, String> pair = Triple.ofNonNull("x", "y", "z");
+        assertEquals("x", pair.getLeft());
+        assertEquals("y", pair.getMiddle());
+        assertEquals("z", pair.getRight());
+    }
+
     @Test
     public void testToString() {
         final Triple<String, String, String> triple = Triple.of("Key", "Something", "Value");
@@ -131,7 +146,7 @@ public class TripleTest {
         assertTrue(triple2 instanceof ImmutableTriple<?, ?, ?>);
         assertNull(((ImmutableTriple<Object, String, Long>) triple2).left);
         assertEquals("bar", ((ImmutableTriple<Object, String, Long>) triple2).middle);
-        assertEquals(new Long(200L), ((ImmutableTriple<Object, String, Long>) triple2).right);
+        assertEquals(Long.valueOf(200L), ((ImmutableTriple<Object, String, Long>) triple2).right);
     }
 
 }
